articleclientv2

package
v0.2.191 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client interface {
	GetArticle(
		ctx context.Context,
		req GetArticleRequest,
		reqEditors ...func(req *http.Request) error,
	) (*articlev2.ReadableArticle, *http.Response, error)
	ListArticles(
		ctx context.Context,
		req ListArticlesRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]articlev2.ReadableArticle, *http.Response, error)
}

func NewClient

func NewClient(client httpclient.RequestRunner) Client

type GetArticleRequest

type GetArticleRequest struct {
	ArticleID  string
	CustomerID *string
}

GetArticleRequest models a request for the 'article-get-article' operation. See 1 for more information.

Get an Article.

func (*GetArticleRequest) BuildRequest

func (r *GetArticleRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListArticlesRequest

type ListArticlesRequest struct {
	CustomerID    *string
	Tags          []string
	TemplateNames []string
	ArticleIDs    []string
	Orderable     []ListArticlesRequestQueryOrderableItem
	Name          *string
	Limit         *int64
	Skip          *int64
	Page          *int64
}

ListArticlesRequest models a request for the 'article-list-articles' operation. See [1] for more information.

List Articles.

[1]: https://developer.mittwald.de/docs/v2/reference/article/article-list-articles

func (*ListArticlesRequest) BuildRequest

func (r *ListArticlesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListArticlesRequestQueryOrderableItem

type ListArticlesRequestQueryOrderableItem string
const ListArticlesRequestQueryOrderableItemBetaTesting ListArticlesRequestQueryOrderableItem = "beta_testing"
const ListArticlesRequestQueryOrderableItemDeprecated ListArticlesRequestQueryOrderableItem = "deprecated"
const ListArticlesRequestQueryOrderableItemForbidden ListArticlesRequestQueryOrderableItem = "forbidden"
const ListArticlesRequestQueryOrderableItemFull ListArticlesRequestQueryOrderableItem = "full"
const ListArticlesRequestQueryOrderableItemInternal ListArticlesRequestQueryOrderableItem = "internal"

func (ListArticlesRequestQueryOrderableItem) Validate

Jump to