containerclientv2

package
v0.2.207 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CallPullImageWebhookForServiceRequest added in v0.2.171

type CallPullImageWebhookForServiceRequest struct {
	StackID string
	Token   string
}

CallPullImageWebhookForServiceRequest models a request for the 'container-call-pull-image-webhook-for-service' operation. See [1] for more information.

Call pull-image webhook

Calls the pull-image webhook endpoint for a Service using a webhook token.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-call-pull-image-webhook-for-service

func (*CallPullImageWebhookForServiceRequest) BuildRequest added in v0.2.171

func (r *CallPullImageWebhookForServiceRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type Client

type Client interface {
	CallPullImageWebhookForService(
		ctx context.Context,
		req CallPullImageWebhookForServiceRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	ListRegistries(
		ctx context.Context,
		req ListRegistriesRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]containerv2.Registry, *http.Response, error)
	CreateRegistry(
		ctx context.Context,
		req CreateRegistryRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.Registry, *http.Response, error)
	ListStacks(
		ctx context.Context,
		req ListStacksRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]containerv2.StackResponse, *http.Response, error)
	CreateStack(
		ctx context.Context,
		req CreateStackRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.StackResponse, *http.Response, error)
	GetStack(
		ctx context.Context,
		req GetStackRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.StackResponse, *http.Response, error)
	DeclareStack(
		ctx context.Context,
		req DeclareStackRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.StackResponse, *http.Response, error)
	DeleteStack(
		ctx context.Context,
		req DeleteStackRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	UpdateStack(
		ctx context.Context,
		req UpdateStackRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.StackResponse, *http.Response, error)
	GetRegistry(
		ctx context.Context,
		req GetRegistryRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.Registry, *http.Response, error)
	DeleteRegistry(
		ctx context.Context,
		req DeleteRegistryRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	UpdateRegistry(
		ctx context.Context,
		req UpdateRegistryRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	GetVolume(
		ctx context.Context,
		req GetVolumeRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.VolumeResponse, *http.Response, error)
	DeleteVolume(
		ctx context.Context,
		req DeleteVolumeRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	GetContainerImageConfig(
		ctx context.Context,
		req GetContainerImageConfigRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.ContainerImageConfig, *http.Response, error)
	GetServiceLogs(
		ctx context.Context,
		req GetServiceLogsRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	GetService(
		ctx context.Context,
		req GetServiceRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.ServiceResponse, *http.Response, error)
	GetTemplate(
		ctx context.Context,
		req GetTemplateRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.Template, *http.Response, error)
	ListSelfStacks(
		ctx context.Context,
		req ListSelfStacksRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]containerv2.StackResponse, *http.Response, error)
	ListServices(
		ctx context.Context,
		req ListServicesRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]containerv2.ServiceResponse, *http.Response, error)
	ListStackVolumes(
		ctx context.Context,
		req ListStackVolumesRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]containerv2.VolumeResponse, *http.Response, error)
	ListTemplates(
		ctx context.Context,
		req ListTemplatesRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]containerv2.Template, *http.Response, error)
	ListVolumes(
		ctx context.Context,
		req ListVolumesRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]containerv2.VolumeResponse, *http.Response, error)
	PullImageForService(
		ctx context.Context,
		req PullImageForServiceRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	RecreateService(
		ctx context.Context,
		req RecreateServiceRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	RestartService(
		ctx context.Context,
		req RestartServiceRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	RotatePullImageWebhookForService(
		ctx context.Context,
		req RotatePullImageWebhookForServiceRequest,
		reqEditors ...func(req *http.Request) error,
	) (*containerv2.ServicePullImageWebhookResponse, *http.Response, error)
	SetStackUpdateSchedule(
		ctx context.Context,
		req SetStackUpdateScheduleRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	StartService(
		ctx context.Context,
		req StartServiceRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	StopService(
		ctx context.Context,
		req StopServiceRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
	DeprecatedValidateContainerRegistryUri(
		ctx context.Context,
		req DeprecatedValidateContainerRegistryUriRequest,
		reqEditors ...func(req *http.Request) error,
	) (*DeprecatedValidateContainerRegistryUriResponse, *http.Response, error)
	DeprecatedValidateRegistryCredentials(
		ctx context.Context,
		req DeprecatedValidateRegistryCredentialsRequest,
		reqEditors ...func(req *http.Request) error,
	) (*DeprecatedValidateRegistryCredentialsResponse, *http.Response, error)
}

func NewClient

func NewClient(client httpclient.RequestRunner) Client

type CreateRegistryRequest

type CreateRegistryRequest struct {
	Body      containerv2.CreateRegistry
	ProjectID string
}

CreateRegistryRequest models a request for the 'container-create-registry' operation. See [1] for more information.

Create a Registry.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-create-registry

func (*CreateRegistryRequest) BuildRequest

func (r *CreateRegistryRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type CreateStackRequest added in v0.2.206

type CreateStackRequest struct {
	Body      containerv2.CreateStack
	ProjectID string
}

CreateStackRequest models a request for the 'container-create-stack' operation. See [1] for more information.

Create a Stack.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-create-stack

func (*CreateStackRequest) BuildRequest added in v0.2.206

func (r *CreateStackRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type DeclareStackRequest

type DeclareStackRequest struct {
	Body    DeclareStackRequestBody
	StackID string
}

DeclareStackRequest models a request for the 'container-declare-stack' operation. See [1] for more information.

Declaratively create, update or delete Services or Volumes belonging to a Stack.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-declare-stack

func (*DeclareStackRequest) BuildRequest

func (r *DeclareStackRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type DeclareStackRequestBody

type DeclareStackRequestBody struct {
	Services map[string]containerv2.ServiceDeclareRequest `json:"services,omitempty"`
	Volumes  map[string]containerv2.VolumeDeclareRequest  `json:"volumes,omitempty"`
}

DeclareStackRequestBody models the JSON body of a 'container-declare-stack' request

func (*DeclareStackRequestBody) Validate

func (o *DeclareStackRequestBody) Validate() error

type DeleteRegistryRequest

type DeleteRegistryRequest struct {
	RegistryID string
}

DeleteRegistryRequest models a request for the 'container-delete-registry' operation. See [1] for more information.

Delete a Registry.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-delete-registry

func (*DeleteRegistryRequest) BuildRequest

func (r *DeleteRegistryRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type DeleteStackRequest added in v0.2.206

type DeleteStackRequest struct {
	StackID string
}

DeleteStackRequest models a request for the 'container-delete-stack' operation. See [1] for more information.

Delete a Stack.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-delete-stack

func (*DeleteStackRequest) BuildRequest added in v0.2.206

func (r *DeleteStackRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type DeleteVolumeRequest

type DeleteVolumeRequest struct {
	StackID  string
	VolumeID string
}

DeleteVolumeRequest models a request for the 'container-delete-volume' operation. See [1] for more information.

Delete a Volume belonging to a Stack.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-delete-volume

func (*DeleteVolumeRequest) BuildRequest

func (r *DeleteVolumeRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type DeprecatedValidateContainerRegistryUriRequest added in v0.2.181

type DeprecatedValidateContainerRegistryUriRequest struct {
	Body DeprecatedValidateContainerRegistryUriRequestBody
}

DeprecatedValidateContainerRegistryUriRequest models a request for the 'deprecated-container-validate-container-registry-uri' operation. See [1] for more information.

Validate a Registries' URI.

Deprecated. Container registry URI validation is performed automatically during resource creation; this endpoint is no longer necessary. This endpoint will be removed in a future version.

[1]: https://developer.mittwald.de/docs/v2/reference/container/deprecated-container-validate-container-registry-uri

func (*DeprecatedValidateContainerRegistryUriRequest) BuildRequest added in v0.2.181

func (r *DeprecatedValidateContainerRegistryUriRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type DeprecatedValidateContainerRegistryUriRequestBody added in v0.2.181

type DeprecatedValidateContainerRegistryUriRequestBody struct {
	RegistryUri string `json:"registryUri"`
}

The Registry URI to validate.

func (*DeprecatedValidateContainerRegistryUriRequestBody) Validate added in v0.2.181

type DeprecatedValidateContainerRegistryUriResponse added in v0.2.181

type DeprecatedValidateContainerRegistryUriResponse struct {
	Reason *string `json:"reason,omitempty"`
	Valid  bool    `json:"valid"`
}

func (*DeprecatedValidateContainerRegistryUriResponse) Validate added in v0.2.181

type DeprecatedValidateRegistryCredentialsRequest added in v0.2.184

type DeprecatedValidateRegistryCredentialsRequest struct {
	RegistryID string
}

DeprecatedValidateRegistryCredentialsRequest models a request for the 'deprecated-container-validate-registry-credentials' operation. See [1] for more information.

Validate a Registries' credentials.

Deprecated. Registry credential validation is performed automatically on a scheduled basis in the backend. This endpoint will be removed in a future version.

[1]: https://developer.mittwald.de/docs/v2/reference/container/deprecated-container-validate-registry-credentials

func (*DeprecatedValidateRegistryCredentialsRequest) BuildRequest added in v0.2.184

func (r *DeprecatedValidateRegistryCredentialsRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type DeprecatedValidateRegistryCredentialsResponse added in v0.2.184

type DeprecatedValidateRegistryCredentialsResponse struct {
	Valid bool `json:"valid"`
}

func (*DeprecatedValidateRegistryCredentialsResponse) Validate added in v0.2.184

type GetContainerImageConfigRequest

type GetContainerImageConfigRequest struct {
	ImageReference              string
	UseCredentialsForProjectID  *string
	UseCredentialsForRegistryID *string
	GenerateAIData              *bool
}

GetContainerImageConfigRequest models a request for the 'container-get-container-image-config' operation. See [1] for more information.

Get a ContainerImageConfig.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-get-container-image-config

func (*GetContainerImageConfigRequest) BuildRequest

func (r *GetContainerImageConfigRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetRegistryRequest

type GetRegistryRequest struct {
	RegistryID string
}

GetRegistryRequest models a request for the 'container-get-registry' operation. See [1] for more information.

Get a Registry.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-get-registry

func (*GetRegistryRequest) BuildRequest

func (r *GetRegistryRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetServiceLogsRequest

type GetServiceLogsRequest struct {
	StackID   string
	ServiceID string
	Tail      *int64
}

GetServiceLogsRequest models a request for the 'container-get-service-logs' operation. See [1] for more information.

Get logs belonging to a Service.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-get-service-logs

func (*GetServiceLogsRequest) BuildRequest

func (r *GetServiceLogsRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetServiceRequest

type GetServiceRequest struct {
	StackID   string
	ServiceID string
}

GetServiceRequest models a request for the 'container-get-service' operation. See [1] for more information.

Get a Service belonging to a Stack.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-get-service

func (*GetServiceRequest) BuildRequest

func (r *GetServiceRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetStackRequest

type GetStackRequest struct {
	StackID string
}

GetStackRequest models a request for the 'container-get-stack' operation. See [1] for more information.

Get a Stack.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-get-stack

func (*GetStackRequest) BuildRequest

func (r *GetStackRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetTemplateRequest added in v0.2.207

type GetTemplateRequest struct {
	TemplateID string
}

GetTemplateRequest models a request for the 'container-get-template' operation. See [1] for more information.

Get a Container Template by ID.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-get-template

func (*GetTemplateRequest) BuildRequest added in v0.2.207

func (r *GetTemplateRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetVolumeRequest

type GetVolumeRequest struct {
	StackID  string
	VolumeID string
}

GetVolumeRequest models a request for the 'container-get-volume' operation. See [1] for more information.

Get a Volume belonging to a Stack.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-get-volume

func (*GetVolumeRequest) BuildRequest

func (r *GetVolumeRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListRegistriesRequest

type ListRegistriesRequest struct {
	ProjectID      string
	HasCredentials *bool
	Limit          *int64
	Skip           *int64
	Page           *int64
}

ListRegistriesRequest models a request for the 'container-list-registries' operation. See [1] for more information.

List Registries belonging to a Project.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-list-registries

func (*ListRegistriesRequest) BuildRequest

func (r *ListRegistriesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListSelfStacksRequest added in v0.2.167

type ListSelfStacksRequest struct {
	SearchTerm *string
	Limit      *int64
	Skip       *int64
	Page       *int64
}

ListSelfStacksRequest models a request for the 'container-list-self-stacks' operation. See [1] for more information.

List Stacks belonging to the executing user.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-list-self-stacks

func (*ListSelfStacksRequest) BuildRequest added in v0.2.167

func (r *ListSelfStacksRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListServicesRequest

type ListServicesRequest struct {
	ProjectID        string
	StackID          *string
	Status           *containerv2.ServiceStatus
	RequiresRecreate *bool
	SearchTerm       *string
	SortOrder        *containerv2.ServiceSortOrder
	Limit            *int64
	Skip             *int64
	Page             *int64
}

ListServicesRequest models a request for the 'container-list-services' operation. See [1] for more information.

List Services belonging to a Project.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-list-services

func (*ListServicesRequest) BuildRequest

func (r *ListServicesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListStackVolumesRequest added in v0.2.106

type ListStackVolumesRequest struct {
	StackID    string
	SearchTerm *string
	SortOrder  *containerv2.VolumeSortOrder
	Limit      *int64
	Skip       *int64
	Page       *int64
}

ListStackVolumesRequest models a request for the 'container-list-stack-volumes' operation. See [1] for more information.

List Volumes belonging to a Stack.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-list-stack-volumes

func (*ListStackVolumesRequest) BuildRequest added in v0.2.106

func (r *ListStackVolumesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListStacksRequest

type ListStacksRequest struct {
	ProjectID string
	Limit     *int64
	Skip      *int64
	Page      *int64
}

ListStacksRequest models a request for the 'container-list-stacks' operation. See [1] for more information.

List Stacks belonging to a Project.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-list-stacks

func (*ListStacksRequest) BuildRequest

func (r *ListStacksRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListTemplatesRequest added in v0.2.207

type ListTemplatesRequest struct {
	Category   *string
	SearchTerm *string
	Limit      *int64
	Skip       *int64
	Page       *int64
}

ListTemplatesRequest models a request for the 'container-list-templates' operation. See [1] for more information.

List Container Templates.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-list-templates

func (*ListTemplatesRequest) BuildRequest added in v0.2.207

func (r *ListTemplatesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListVolumesRequest

type ListVolumesRequest struct {
	ProjectID  string
	StackID    *string
	SearchTerm *string
	SortOrder  *containerv2.VolumeSortOrder
	Limit      *int64
	Skip       *int64
	Page       *int64
}

ListVolumesRequest models a request for the 'container-list-volumes' operation. See [1] for more information.

List Volumes belonging to a Project.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-list-volumes

func (*ListVolumesRequest) BuildRequest

func (r *ListVolumesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type PullImageForServiceRequest

type PullImageForServiceRequest struct {
	StackID      string
	ServiceID    string
	SkipRecreate *bool
}

PullImageForServiceRequest models a request for the 'container-pull-image-for-service' operation. See [1] for more information.

Pull image and recreate

Pulls the latest image for this container and recreates it.

You can skip re-creation by setting the `skipRecreate` query parameter.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-pull-image-for-service

func (*PullImageForServiceRequest) BuildRequest

func (r *PullImageForServiceRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type RecreateServiceRequest

type RecreateServiceRequest struct {
	StackID   string
	ServiceID string
}

RecreateServiceRequest models a request for the 'container-recreate-service' operation. See [1] for more information.

Recreate a Service.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-recreate-service

func (*RecreateServiceRequest) BuildRequest

func (r *RecreateServiceRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type RestartServiceRequest

type RestartServiceRequest struct {
	StackID   string
	ServiceID string
}

RestartServiceRequest models a request for the 'container-restart-service' operation. See [1] for more information.

Restart a started Service.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-restart-service

func (*RestartServiceRequest) BuildRequest

func (r *RestartServiceRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type RotatePullImageWebhookForServiceRequest added in v0.2.171

type RotatePullImageWebhookForServiceRequest struct {
	StackID   string
	ServiceID string
}

RotatePullImageWebhookForServiceRequest models a request for the 'container-rotate-pull-image-webhook-for-service' operation. See [1] for more information.

Create or rotate pull-image webhook token

Creates or rotates the pull-image webhook token for a Service.

The returned token is shown only once.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-rotate-pull-image-webhook-for-service

func (*RotatePullImageWebhookForServiceRequest) BuildRequest added in v0.2.171

func (r *RotatePullImageWebhookForServiceRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type SetStackUpdateScheduleRequest added in v0.2.163

type SetStackUpdateScheduleRequest struct {
	Body    SetStackUpdateScheduleRequestBody
	StackID string
}

SetStackUpdateScheduleRequest models a request for the 'container-set-stack-update-schedule' operation. See [1] for more information.

Set an update schedule for a Stack.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-set-stack-update-schedule

func (*SetStackUpdateScheduleRequest) BuildRequest added in v0.2.163

func (r *SetStackUpdateScheduleRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type SetStackUpdateScheduleRequestBody added in v0.2.163

type SetStackUpdateScheduleRequestBody struct {
	UpdateSchedule *SetStackUpdateScheduleRequestBodyUpdateSchedule `json:"updateSchedule,omitempty"`
}

SetStackUpdateScheduleRequestBody models the JSON body of a 'container-set-stack-update-schedule' request

func (*SetStackUpdateScheduleRequestBody) Validate added in v0.2.163

type SetStackUpdateScheduleRequestBodyUpdateSchedule added in v0.2.163

type SetStackUpdateScheduleRequestBodyUpdateSchedule struct {
	Cron     string  `json:"cron"`
	Timezone *string `json:"timezone,omitempty"`
}

func (*SetStackUpdateScheduleRequestBodyUpdateSchedule) Validate added in v0.2.163

type StartServiceRequest

type StartServiceRequest struct {
	StackID   string
	ServiceID string
}

StartServiceRequest models a request for the 'container-start-service' operation. See [1] for more information.

Start a stopped Service.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-start-service

func (*StartServiceRequest) BuildRequest

func (r *StartServiceRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type StopServiceRequest

type StopServiceRequest struct {
	StackID   string
	ServiceID string
}

StopServiceRequest models a request for the 'container-stop-service' operation. See [1] for more information.

Stop a started Service.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-stop-service

func (*StopServiceRequest) BuildRequest

func (r *StopServiceRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type UpdateRegistryRequest

type UpdateRegistryRequest struct {
	Body       containerv2.UpdateRegistry
	RegistryID string
}

UpdateRegistryRequest models a request for the 'container-update-registry' operation. See [1] for more information.

Update a Registry.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-update-registry

func (*UpdateRegistryRequest) BuildRequest

func (r *UpdateRegistryRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type UpdateStackRequest

type UpdateStackRequest struct {
	Body     UpdateStackRequestBody
	StackID  string
	Recreate *bool
}

UpdateStackRequest models a request for the 'container-update-stack' operation. See [1] for more information.

Create, update or delete Services or Volumes belonging to a Stack.

[1]: https://developer.mittwald.de/docs/v2/reference/container/container-update-stack

func (*UpdateStackRequest) BuildRequest

func (r *UpdateStackRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type UpdateStackRequestBody

type UpdateStackRequestBody struct {
	Description *string                               `json:"description,omitempty"`
	Services    map[string]containerv2.ServiceRequest `json:"services,omitempty"`
	Volumes     map[string]containerv2.VolumeRequest  `json:"volumes,omitempty"`
}

UpdateStackRequestBody models the JSON body of a 'container-update-stack' request

func (*UpdateStackRequestBody) Validate

func (o *UpdateStackRequestBody) Validate() error

Jump to