contractclientv2

package
v0.2.187 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CancelContractItemTerminationRequest

type CancelContractItemTerminationRequest struct {
	ContractID     string
	ContractItemID string
}

CancelContractItemTerminationRequest models a request for the 'contract-cancel-contract-item-termination' operation. See [1] for more information.

Cancel the Termination for the referred ContractItem.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-cancel-contract-item-termination

func (*CancelContractItemTerminationRequest) BuildRequest

func (r *CancelContractItemTerminationRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type CancelContractItemTerminationResponse

type CancelContractItemTerminationResponse struct {
	ContractId     *string `json:"contractId,omitempty"`
	ContractItemId *string `json:"contractItemId,omitempty"`
	IsCancelled    *bool   `json:"isCancelled,omitempty"`
}

func (*CancelContractItemTerminationResponse) Validate

type CancelContractTariffChangeRequest

type CancelContractTariffChangeRequest struct {
	ContractID     string
	ContractItemID string
}

CancelContractTariffChangeRequest models a request for the 'contract-cancel-contract-tariff-change' operation. See [1] for more information.

Cancel the TariffChange for the referred ContractItem.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-cancel-contract-tariff-change

func (*CancelContractTariffChangeRequest) BuildRequest

func (r *CancelContractTariffChangeRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type CancelContractTariffChangeResponse

type CancelContractTariffChangeResponse struct {
	ContractId     *string `json:"contractId,omitempty"`
	ContractItemId *string `json:"contractItemId,omitempty"`
	IsCancelled    *bool   `json:"isCancelled,omitempty"`
}

func (*CancelContractTariffChangeResponse) Validate

type CancelContractTerminationRequest

type CancelContractTerminationRequest struct {
	ContractID string
}

CancelContractTerminationRequest models a request for the 'contract-cancel-contract-termination' operation. See [1] for more information.

Cancel the Termination for the referred Contract.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-cancel-contract-termination

func (*CancelContractTerminationRequest) BuildRequest

func (r *CancelContractTerminationRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type CancelContractTerminationResponse

type CancelContractTerminationResponse struct {
	ContractId  *string `json:"contractId,omitempty"`
	IsCancelled *bool   `json:"isCancelled,omitempty"`
}

func (*CancelContractTerminationResponse) Validate

type Client

type Client interface {
	TerminateContractItem(
		ctx context.Context,
		req TerminateContractItemRequest,
		reqEditors ...func(req *http.Request) error,
	) (*TerminateContractItemResponse, *http.Response, error)
	CancelContractItemTermination(
		ctx context.Context,
		req CancelContractItemTerminationRequest,
		reqEditors ...func(req *http.Request) error,
	) (*CancelContractItemTerminationResponse, *http.Response, error)
	CancelContractTariffChange(
		ctx context.Context,
		req CancelContractTariffChangeRequest,
		reqEditors ...func(req *http.Request) error,
	) (*CancelContractTariffChangeResponse, *http.Response, error)
	TerminateContract(
		ctx context.Context,
		req TerminateContractRequest,
		reqEditors ...func(req *http.Request) error,
	) (*TerminateContractResponse, *http.Response, error)
	CancelContractTermination(
		ctx context.Context,
		req CancelContractTerminationRequest,
		reqEditors ...func(req *http.Request) error,
	) (*CancelContractTerminationResponse, *http.Response, error)
	GetBaseItemOfContract(
		ctx context.Context,
		req GetBaseItemOfContractRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.ContractItem, *http.Response, error)
	GetDetailOfContractByAIHosting(
		ctx context.Context,
		req GetDetailOfContractByAIHostingRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.Contract, *http.Response, error)
	GetDetailOfContractByCertificate(
		ctx context.Context,
		req GetDetailOfContractByCertificateRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.Contract, *http.Response, error)
	GetDetailOfContractByDomain(
		ctx context.Context,
		req GetDetailOfContractByDomainRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.Contract, *http.Response, error)
	GetDetailOfContractByLeadFyndr(
		ctx context.Context,
		req GetDetailOfContractByLeadFyndrRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.Contract, *http.Response, error)
	GetDetailOfContractByLicense(
		ctx context.Context,
		req GetDetailOfContractByLicenseRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.Contract, *http.Response, error)
	GetDetailOfContractByMailAddress(
		ctx context.Context,
		req GetDetailOfContractByMailAddressRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.Contract, *http.Response, error)
	GetDetailOfContractByProject(
		ctx context.Context,
		req GetDetailOfContractByProjectRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.Contract, *http.Response, error)
	GetDetailOfContractByServer(
		ctx context.Context,
		req GetDetailOfContractByServerRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.Contract, *http.Response, error)
	GetDetailOfContractItem(
		ctx context.Context,
		req GetDetailOfContractItemRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.ContractItem, *http.Response, error)
	GetDetailOfContract(
		ctx context.Context,
		req GetDetailOfContractRequest,
		reqEditors ...func(req *http.Request) error,
	) (*contractv2.Contract, *http.Response, error)
	ListContracts(
		ctx context.Context,
		req ListContractsRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]contractv2.Contract, *http.Response, error)
	DeprecatedGetNextTerminationDateForItem(
		ctx context.Context,
		req DeprecatedGetNextTerminationDateForItemRequest,
		reqEditors ...func(req *http.Request) error,
	) (*DeprecatedGetNextTerminationDateForItemResponse, *http.Response, error)
	DeprecatedInvoiceDetailOfInvoice(
		ctx context.Context,
		req DeprecatedInvoiceDetailOfInvoiceRequest,
		reqEditors ...func(req *http.Request) error,
	) (*invoicev2.Invoice, *http.Response, error)
	InvoiceDetail(
		ctx context.Context,
		req InvoiceDetailRequest,
		reqEditors ...func(req *http.Request) error,
	) (*invoicev2.Invoice, *http.Response, error)
	InvoiceGetDetailOfInvoiceSettings(
		ctx context.Context,
		req InvoiceGetDetailOfInvoiceSettingsRequest,
		reqEditors ...func(req *http.Request) error,
	) (*invoicev2.InvoiceSettings, *http.Response, error)
	InvoiceUpdateInvoiceSettings(
		ctx context.Context,
		req InvoiceUpdateInvoiceSettingsRequest,
		reqEditors ...func(req *http.Request) error,
	) (*invoicev2.InvoiceSettings, *http.Response, error)
	InvoiceGetFileAccessToken(
		ctx context.Context,
		req InvoiceGetFileAccessTokenRequest,
		reqEditors ...func(req *http.Request) error,
	) (*InvoiceGetFileAccessTokenResponse, *http.Response, error)
	InvoiceListCustomerInvoices(
		ctx context.Context,
		req InvoiceListCustomerInvoicesRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]invoicev2.Invoice, *http.Response, error)
	ListOrders(
		ctx context.Context,
		req ListOrdersRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]orderv2.CustomerOrder, *http.Response, error)
	CreateOrder(
		ctx context.Context,
		req CreateOrderRequest,
		reqEditors ...func(req *http.Request) error,
	) (*CreateOrderResponse, *http.Response, error)
	CreateTariffChange(
		ctx context.Context,
		req CreateTariffChangeRequest,
		reqEditors ...func(req *http.Request) error,
	) (*CreateTariffChangeResponse, *http.Response, error)
	GetOrder(
		ctx context.Context,
		req GetOrderRequest,
		reqEditors ...func(req *http.Request) error,
	) (*orderv2.CustomerOrder, *http.Response, error)
	ListCustomerOrders(
		ctx context.Context,
		req ListCustomerOrdersRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]orderv2.CustomerOrder, *http.Response, error)
	ListProjectOrders(
		ctx context.Context,
		req ListProjectOrdersRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]orderv2.CustomerOrder, *http.Response, error)
	PreviewOrder(
		ctx context.Context,
		req PreviewOrderRequest,
		reqEditors ...func(req *http.Request) error,
	) (*any, *http.Response, error)
	PreviewTariffChange(
		ctx context.Context,
		req PreviewTariffChangeRequest,
		reqEditors ...func(req *http.Request) error,
	) (*PreviewTariffChangeResponse, *http.Response, error)
}

func NewClient

func NewClient(client httpclient.RequestRunner) Client

type CreateOrderRequest

type CreateOrderRequest struct {
	Body CreateOrderRequestBody
}

CreateOrderRequest models a request for the 'order-create-order' operation. See 1 for more information.

Create an Order.

func (*CreateOrderRequest) BuildRequest

func (r *CreateOrderRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type CreateOrderRequestBody

type CreateOrderRequestBody struct {
	OrderData *CreateOrderRequestBodyOrderData `json:"orderData,omitempty"`
	OrderType *CreateOrderRequestBodyOrderType `json:"orderType,omitempty"`
}

CreateOrderRequestBody models the JSON body of a 'order-create-order' request

func (*CreateOrderRequestBody) Validate

func (o *CreateOrderRequestBody) Validate() error

type CreateOrderRequestBodyOrderData

type CreateOrderRequestBodyOrderData struct {
	AlternativeProjectHostingOrder      *orderv2.ProjectHostingOrder
	AlternativeServerOrder              *orderv2.ServerOrder
	AlternativeDomainOrder              *orderv2.DomainOrder
	AlternativeExternalCertificateOrder *orderv2.ExternalCertificateOrder
	AlternativeLeadFyndrOrder           *orderv2.LeadFyndrOrder
	AlternativeMailArchiveOrder         *orderv2.MailArchiveOrder
	AlternativeAIHostingOrder           *orderv2.AIHostingOrder
	AlternativeLicenseOrder             *orderv2.LicenseOrder
}

func (*CreateOrderRequestBodyOrderData) MarshalJSON

func (a *CreateOrderRequestBodyOrderData) MarshalJSON() ([]byte, error)

func (*CreateOrderRequestBodyOrderData) UnmarshalJSON

func (a *CreateOrderRequestBodyOrderData) UnmarshalJSON(input []byte) error

func (*CreateOrderRequestBodyOrderData) Validate

func (a *CreateOrderRequestBodyOrderData) Validate() error

type CreateOrderRequestBodyOrderType

type CreateOrderRequestBodyOrderType string
const CreateOrderRequestBodyOrderTypeAIHosting CreateOrderRequestBodyOrderType = "aiHosting"
const CreateOrderRequestBodyOrderTypeDomain CreateOrderRequestBodyOrderType = "domain"
const CreateOrderRequestBodyOrderTypeExternalCertificate CreateOrderRequestBodyOrderType = "externalCertificate"
const CreateOrderRequestBodyOrderTypeLeadFyndr CreateOrderRequestBodyOrderType = "leadFyndr"
const CreateOrderRequestBodyOrderTypeLicense CreateOrderRequestBodyOrderType = "license"
const CreateOrderRequestBodyOrderTypeMailArchive CreateOrderRequestBodyOrderType = "mailArchive"
const CreateOrderRequestBodyOrderTypeProjectHosting CreateOrderRequestBodyOrderType = "projectHosting"
const CreateOrderRequestBodyOrderTypeServer CreateOrderRequestBodyOrderType = "server"

func (CreateOrderRequestBodyOrderType) Validate

type CreateOrderResponse

type CreateOrderResponse struct {
	OrderId string `json:"orderId"`
}

func (*CreateOrderResponse) Validate

func (o *CreateOrderResponse) Validate() error

type CreateTariffChangeRequest

type CreateTariffChangeRequest struct {
	Body CreateTariffChangeRequestBody
}

CreateTariffChangeRequest models a request for the 'order-create-tariff-change' operation. See [1] for more information.

Create TariffChange Order.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/order-create-tariff-change

func (*CreateTariffChangeRequest) BuildRequest

func (r *CreateTariffChangeRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type CreateTariffChangeRequestBody

type CreateTariffChangeRequestBody struct {
	TariffChangeData *CreateTariffChangeRequestBodyTariffChangeData `json:"tariffChangeData,omitempty"`
	TariffChangeType *CreateTariffChangeRequestBodyTariffChangeType `json:"tariffChangeType,omitempty"`
}

CreateTariffChangeRequestBody models the JSON body of a 'order-create-tariff-change' request

func (*CreateTariffChangeRequestBody) Validate

func (o *CreateTariffChangeRequestBody) Validate() error

type CreateTariffChangeRequestBodyTariffChangeData

type CreateTariffChangeRequestBodyTariffChangeData struct {
	AlternativeProjectHostingTariffChange *orderv2.ProjectHostingTariffChange
	AlternativeServerTariffChange         *orderv2.ServerTariffChange
	AlternativeLeadFyndrTariffChange      *orderv2.LeadFyndrTariffChange
	AlternativeAIHostingTariffChange      *orderv2.AIHostingTariffChange
}

func (*CreateTariffChangeRequestBodyTariffChangeData) MarshalJSON

func (*CreateTariffChangeRequestBodyTariffChangeData) UnmarshalJSON

func (a *CreateTariffChangeRequestBodyTariffChangeData) UnmarshalJSON(input []byte) error

func (*CreateTariffChangeRequestBodyTariffChangeData) Validate

type CreateTariffChangeRequestBodyTariffChangeType

type CreateTariffChangeRequestBodyTariffChangeType string
const CreateTariffChangeRequestBodyTariffChangeTypeAIHosting CreateTariffChangeRequestBodyTariffChangeType = "aiHosting"
const CreateTariffChangeRequestBodyTariffChangeTypeLeadFyndr CreateTariffChangeRequestBodyTariffChangeType = "leadFyndr"
const CreateTariffChangeRequestBodyTariffChangeTypeProjectHosting CreateTariffChangeRequestBodyTariffChangeType = "projectHosting"
const CreateTariffChangeRequestBodyTariffChangeTypeServer CreateTariffChangeRequestBodyTariffChangeType = "server"

func (CreateTariffChangeRequestBodyTariffChangeType) Validate

type CreateTariffChangeResponse

type CreateTariffChangeResponse struct {
	OrderId string `json:"orderId"`
}

func (*CreateTariffChangeResponse) Validate

func (o *CreateTariffChangeResponse) Validate() error

type DeprecatedGetNextTerminationDateForItemRequest added in v0.2.63

type DeprecatedGetNextTerminationDateForItemRequest struct {
	ContractID     string
	ContractItemID string
}

DeprecatedGetNextTerminationDateForItemRequest models a request for the 'deprecated-contract-get-next-termination-date-for-item' operation. See [1] for more information.

Return the next TerminationDate for the ContractItem with the given ID.

This route is deprecated. Use GET /v2/contracts/{contractId}/items/{contractItemId} instead.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/deprecated-contract-get-next-termination-date-for-item

func (*DeprecatedGetNextTerminationDateForItemRequest) BuildRequest added in v0.2.63

func (r *DeprecatedGetNextTerminationDateForItemRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type DeprecatedGetNextTerminationDateForItemResponse added in v0.2.63

type DeprecatedGetNextTerminationDateForItemResponse struct {
	ContractItemId      string    `json:"contractItemId"`
	NextTerminationDate time.Time `json:"nextTerminationDate"`
}

func (*DeprecatedGetNextTerminationDateForItemResponse) Validate added in v0.2.63

type DeprecatedInvoiceDetailOfInvoiceRequest

type DeprecatedInvoiceDetailOfInvoiceRequest struct {
	CustomerID string
	InvoiceID  string
}

DeprecatedInvoiceDetailOfInvoiceRequest models a request for the 'deprecated-invoice-detail-of-invoice' operation. See [1] for more information.

Get details of an Invoice.

This route is deprecated. Use /v2/invoices/{invoiceId} instead.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/deprecated-invoice-detail-of-invoice

func (*DeprecatedInvoiceDetailOfInvoiceRequest) BuildRequest

func (r *DeprecatedInvoiceDetailOfInvoiceRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetBaseItemOfContractRequest

type GetBaseItemOfContractRequest struct {
	ContractID string
}

GetBaseItemOfContractRequest models a request for the 'contract-get-base-item-of-contract' operation. See [1] for more information.

Return the BaseItem of the Contract with the given ID.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-base-item-of-contract

func (*GetBaseItemOfContractRequest) BuildRequest

func (r *GetBaseItemOfContractRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetDetailOfContractByAIHostingRequest added in v0.2.143

type GetDetailOfContractByAIHostingRequest struct {
	CustomerID string
}

GetDetailOfContractByAIHostingRequest models a request for the 'contract-get-detail-of-contract-by-ai-hosting' operation. See [1] for more information.

Return the AI Hosting Contract for the given Customer.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-detail-of-contract-by-ai-hosting

func (*GetDetailOfContractByAIHostingRequest) BuildRequest added in v0.2.143

func (r *GetDetailOfContractByAIHostingRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetDetailOfContractByCertificateRequest

type GetDetailOfContractByCertificateRequest struct {
	CertificateID string
}

GetDetailOfContractByCertificateRequest models a request for the 'contract-get-detail-of-contract-by-certificate' operation. See [1] for more information.

Return the Contract for the given Certificate.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-detail-of-contract-by-certificate

func (*GetDetailOfContractByCertificateRequest) BuildRequest

func (r *GetDetailOfContractByCertificateRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetDetailOfContractByDomainRequest

type GetDetailOfContractByDomainRequest struct {
	DomainID string
}

GetDetailOfContractByDomainRequest models a request for the 'contract-get-detail-of-contract-by-domain' operation. See [1] for more information.

Return the Contract for the given Domain.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-detail-of-contract-by-domain

func (*GetDetailOfContractByDomainRequest) BuildRequest

func (r *GetDetailOfContractByDomainRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetDetailOfContractByLeadFyndrRequest added in v0.2.47

type GetDetailOfContractByLeadFyndrRequest struct {
	CustomerID string
}

GetDetailOfContractByLeadFyndrRequest models a request for the 'contract-get-detail-of-contract-by-lead-fyndr' operation. See [1] for more information.

Return the Contract for the given LeadFyndrProfile.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-detail-of-contract-by-lead-fyndr

func (*GetDetailOfContractByLeadFyndrRequest) BuildRequest added in v0.2.47

func (r *GetDetailOfContractByLeadFyndrRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetDetailOfContractByLicenseRequest added in v0.2.160

type GetDetailOfContractByLicenseRequest struct {
	LicenseID string
}

GetDetailOfContractByLicenseRequest models a request for the 'contract-get-detail-of-contract-by-license' operation. See [1] for more information.

Return the Contract for the given License.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-detail-of-contract-by-license

func (*GetDetailOfContractByLicenseRequest) BuildRequest added in v0.2.160

func (r *GetDetailOfContractByLicenseRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetDetailOfContractByMailAddressRequest added in v0.2.85

type GetDetailOfContractByMailAddressRequest struct {
	MailAddressID string
}

GetDetailOfContractByMailAddressRequest models a request for the 'contract-get-detail-of-contract-by-mail-address' operation. See [1] for more information.

Return the Contract for the given Mail Address.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-detail-of-contract-by-mail-address

func (*GetDetailOfContractByMailAddressRequest) BuildRequest added in v0.2.85

func (r *GetDetailOfContractByMailAddressRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetDetailOfContractByProjectRequest

type GetDetailOfContractByProjectRequest struct {
	ProjectID string
}

GetDetailOfContractByProjectRequest models a request for the 'contract-get-detail-of-contract-by-project' operation. See [1] for more information.

Return the Contract for the given Project.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-detail-of-contract-by-project

func (*GetDetailOfContractByProjectRequest) BuildRequest

func (r *GetDetailOfContractByProjectRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetDetailOfContractByServerRequest

type GetDetailOfContractByServerRequest struct {
	ServerID string
}

GetDetailOfContractByServerRequest models a request for the 'contract-get-detail-of-contract-by-server' operation. See [1] for more information.

Return the Contract for the given Server.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-detail-of-contract-by-server

func (*GetDetailOfContractByServerRequest) BuildRequest

func (r *GetDetailOfContractByServerRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetDetailOfContractItemRequest

type GetDetailOfContractItemRequest struct {
	ContractID     string
	ContractItemID string
}

GetDetailOfContractItemRequest models a request for the 'contract-get-detail-of-contract-item' operation. See [1] for more information.

Get the ContractItem with the given ID.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-detail-of-contract-item

func (*GetDetailOfContractItemRequest) BuildRequest

func (r *GetDetailOfContractItemRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetDetailOfContractRequest

type GetDetailOfContractRequest struct {
	ContractID string
}

GetDetailOfContractRequest models a request for the 'contract-get-detail-of-contract' operation. See [1] for more information.

Returns the Contract with the given ID.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-get-detail-of-contract

func (*GetDetailOfContractRequest) BuildRequest

func (r *GetDetailOfContractRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type GetOrderRequest

type GetOrderRequest struct {
	OrderID string
}

GetOrderRequest models a request for the 'order-get-order' operation. See 1 for more information.

Get Order for Customer.

Get details of a single Order, User must have access to the Order/Customer.

func (*GetOrderRequest) BuildRequest

func (r *GetOrderRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type InvoiceDetailRequest

type InvoiceDetailRequest struct {
	InvoiceID string
}

InvoiceDetailRequest models a request for the 'invoice-detail' operation. See 1 for more information.

Get details of an Invoice.

func (*InvoiceDetailRequest) BuildRequest

func (r *InvoiceDetailRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type InvoiceGetDetailOfInvoiceSettingsRequest

type InvoiceGetDetailOfInvoiceSettingsRequest struct {
	CustomerID string
}

InvoiceGetDetailOfInvoiceSettingsRequest models a request for the 'invoice-get-detail-of-invoice-settings' operation. See [1] for more information.

Get InvoiceSettings of a Customer.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/invoice-get-detail-of-invoice-settings

func (*InvoiceGetDetailOfInvoiceSettingsRequest) BuildRequest

func (r *InvoiceGetDetailOfInvoiceSettingsRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type InvoiceGetFileAccessTokenRequest

type InvoiceGetFileAccessTokenRequest struct {
	CustomerID string
	InvoiceID  string
}

InvoiceGetFileAccessTokenRequest models a request for the 'invoice-get-file-access-token' operation. See [1] for more information.

Request an Access Token for the Invoice file.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/invoice-get-file-access-token

func (*InvoiceGetFileAccessTokenRequest) BuildRequest

func (r *InvoiceGetFileAccessTokenRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type InvoiceGetFileAccessTokenResponse

type InvoiceGetFileAccessTokenResponse struct {
	AccessToken string    `json:"accessToken"`
	ExpiresAt   time.Time `json:"expiresAt"`
}

func (*InvoiceGetFileAccessTokenResponse) Validate

type InvoiceListCustomerInvoicesRequest

InvoiceListCustomerInvoicesRequest models a request for the 'invoice-list-customer-invoices' operation. See [1] for more information.

List Invoices of a Customer.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/invoice-list-customer-invoices

func (*InvoiceListCustomerInvoicesRequest) BuildRequest

func (r *InvoiceListCustomerInvoicesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItem

type InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItem string
const InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItemCANCELLATION InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItem = "CANCELLATION"
const InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItemCORRECTION InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItem = "CORRECTION"
const InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItemREGULAR InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItem = "REGULAR"
const InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItemREISSUE InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItem = "REISSUE"

func (InvoiceListCustomerInvoicesRequestQueryInvoiceTypesItem) Validate

type InvoiceListCustomerInvoicesRequestQueryOrderItem added in v0.2.64

type InvoiceListCustomerInvoicesRequestQueryOrderItem string
const InvoiceListCustomerInvoicesRequestQueryOrderItemAsc InvoiceListCustomerInvoicesRequestQueryOrderItem = "asc"
const InvoiceListCustomerInvoicesRequestQueryOrderItemDesc InvoiceListCustomerInvoicesRequestQueryOrderItem = "desc"

func (InvoiceListCustomerInvoicesRequestQueryOrderItem) Validate added in v0.2.64

type InvoiceListCustomerInvoicesRequestQuerySortItem added in v0.2.64

type InvoiceListCustomerInvoicesRequestQuerySortItem string
const InvoiceListCustomerInvoicesRequestQuerySortItemInvoiceNumber InvoiceListCustomerInvoicesRequestQuerySortItem = "invoiceNumber"

func (InvoiceListCustomerInvoicesRequestQuerySortItem) Validate added in v0.2.64

type InvoiceListCustomerInvoicesRequestQueryStatusItem added in v0.2.91

type InvoiceListCustomerInvoicesRequestQueryStatusItem string
const InvoiceListCustomerInvoicesRequestQueryStatusItemCONFIRMED InvoiceListCustomerInvoicesRequestQueryStatusItem = "CONFIRMED"
const InvoiceListCustomerInvoicesRequestQueryStatusItemOVERPAID InvoiceListCustomerInvoicesRequestQueryStatusItem = "OVERPAID"
const InvoiceListCustomerInvoicesRequestQueryStatusItemPAID InvoiceListCustomerInvoicesRequestQueryStatusItem = "PAID"
const InvoiceListCustomerInvoicesRequestQueryStatusItemPARTIALLYPAID InvoiceListCustomerInvoicesRequestQueryStatusItem = "PARTIALLY_PAID"

func (InvoiceListCustomerInvoicesRequestQueryStatusItem) Validate added in v0.2.91

type InvoiceUpdateInvoiceSettingsRequest

type InvoiceUpdateInvoiceSettingsRequest struct {
	Body       InvoiceUpdateInvoiceSettingsRequestBody
	CustomerID string
}

InvoiceUpdateInvoiceSettingsRequest models a request for the 'invoice-update-invoice-settings' operation. See [1] for more information.

Update InvoiceSettings of a Customer.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/invoice-update-invoice-settings

func (*InvoiceUpdateInvoiceSettingsRequest) BuildRequest

func (r *InvoiceUpdateInvoiceSettingsRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type InvoiceUpdateInvoiceSettingsRequestBody

type InvoiceUpdateInvoiceSettingsRequestBody struct {
	AdditionalEmailRecipients []string                  `json:"additionalEmailRecipients,omitempty"`
	InvoicePeriod             int64                     `json:"invoicePeriod"`
	PaymentSettings           invoicev2.PaymentSettings `json:"paymentSettings"`
	PrintedInvoices           *bool                     `json:"printedInvoices,omitempty"`
	Recipient                 *invoicev2.Recipient      `json:"recipient,omitempty"`
	RecipientSameAsOwner      *bool                     `json:"recipientSameAsOwner,omitempty"`
	TargetDay                 *int64                    `json:"targetDay,omitempty"`
}

InvoiceUpdateInvoiceSettingsRequestBody models the JSON body of a 'invoice-update-invoice-settings' request

func (*InvoiceUpdateInvoiceSettingsRequestBody) Validate

type ListContractsRequest

type ListContractsRequest struct {
	CustomerID string
	Limit      *int64
	Skip       *int64
	Page       *int64
}

ListContractsRequest models a request for the 'contract-list-contracts' operation. See [1] for more information.

Return a list of Contracts for the given Customer.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-list-contracts

func (*ListContractsRequest) BuildRequest

func (r *ListContractsRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListCustomerOrdersRequest

type ListCustomerOrdersRequest struct {
	CustomerID     string
	Limit          *int64
	Skip           *int64
	Page           *int64
	IncludesStatus []orderv2.OrderStatus
	ExcludesStatus []orderv2.OrderStatus
	TemplateNames  []string
}

ListCustomerOrdersRequest models a request for the 'order-list-customer-orders' operation. See [1] for more information.

Get list of Orders of a Customer.

The list of Orders of a Customer the User has access to, can be filtered by orderStatus, articleTemplate and count.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/order-list-customer-orders

func (*ListCustomerOrdersRequest) BuildRequest

func (r *ListCustomerOrdersRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListOrdersRequest

type ListOrdersRequest struct {
	IncludesStatus []orderv2.OrderStatus
	ExcludesStatus []orderv2.OrderStatus
	TemplateNames  []string
	Types          []orderv2.OrderType
	Limit          *int64
	Skip           *int64
	Page           *int64
}

ListOrdersRequest models a request for the 'order-list-orders' operation. See 1 for more information.

Get list of Orders.

The list of Orders the User has access to.

func (*ListOrdersRequest) BuildRequest

func (r *ListOrdersRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ListProjectOrdersRequest

type ListProjectOrdersRequest struct {
	ProjectID      string
	Limit          *int64
	Skip           *int64
	Page           *int64
	IncludesStatus []orderv2.OrderStatus
	ExcludesStatus []orderv2.OrderStatus
	TemplateNames  []string
}

ListProjectOrdersRequest models a request for the 'order-list-project-orders' operation. See [1] for more information.

Get list of Orders of a Project.

The list of Order of a Project the User has access to, can be filtered by orderStatus, articleTemplate and count.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/order-list-project-orders

func (*ListProjectOrdersRequest) BuildRequest

func (r *ListProjectOrdersRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type PreviewOrderRequest

type PreviewOrderRequest struct {
	Body PreviewOrderRequestBody
}

PreviewOrderRequest models a request for the 'order-preview-order' operation. See [1] for more information.

Preview Order.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/order-preview-order

func (*PreviewOrderRequest) BuildRequest

func (r *PreviewOrderRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type PreviewOrderRequestBody

type PreviewOrderRequestBody struct {
	OrderData *PreviewOrderRequestBodyOrderData `json:"orderData,omitempty"`
	OrderType *PreviewOrderRequestBodyOrderType `json:"orderType,omitempty"`
}

PreviewOrderRequestBody models the JSON body of a 'order-preview-order' request

func (*PreviewOrderRequestBody) Validate

func (o *PreviewOrderRequestBody) Validate() error

type PreviewOrderRequestBodyOrderData

type PreviewOrderRequestBodyOrderData struct {
	AlternativeProjectHostingOrderPreview      *orderv2.ProjectHostingOrderPreview
	AlternativeServerOrderPreview              *orderv2.ServerOrderPreview
	AlternativeDomainOrderPreview              *orderv2.DomainOrderPreview
	AlternativeExternalCertificateOrderPreview *orderv2.ExternalCertificateOrderPreview
	AlternativeLeadFyndrOrderPreview           *orderv2.LeadFyndrOrderPreview
	AlternativeMailArchiveOrderPreview         *orderv2.MailArchiveOrderPreview
	AlternativeAIHostingOrderPreview           *orderv2.AIHostingOrderPreview
	AlternativeLicenseOrderPreview             *orderv2.LicenseOrderPreview
}

func (*PreviewOrderRequestBodyOrderData) MarshalJSON

func (a *PreviewOrderRequestBodyOrderData) MarshalJSON() ([]byte, error)

func (*PreviewOrderRequestBodyOrderData) UnmarshalJSON

func (a *PreviewOrderRequestBodyOrderData) UnmarshalJSON(input []byte) error

func (*PreviewOrderRequestBodyOrderData) Validate

type PreviewOrderRequestBodyOrderType

type PreviewOrderRequestBodyOrderType string
const PreviewOrderRequestBodyOrderTypeAIHosting PreviewOrderRequestBodyOrderType = "aiHosting"
const PreviewOrderRequestBodyOrderTypeDomain PreviewOrderRequestBodyOrderType = "domain"
const PreviewOrderRequestBodyOrderTypeExternalCertificate PreviewOrderRequestBodyOrderType = "externalCertificate"
const PreviewOrderRequestBodyOrderTypeLeadFyndr PreviewOrderRequestBodyOrderType = "leadFyndr"
const PreviewOrderRequestBodyOrderTypeLicense PreviewOrderRequestBodyOrderType = "license"
const PreviewOrderRequestBodyOrderTypeMailArchive PreviewOrderRequestBodyOrderType = "mailArchive"
const PreviewOrderRequestBodyOrderTypeProjectHosting PreviewOrderRequestBodyOrderType = "projectHosting"
const PreviewOrderRequestBodyOrderTypeServer PreviewOrderRequestBodyOrderType = "server"

func (PreviewOrderRequestBodyOrderType) Validate

type PreviewTariffChangeRequest

type PreviewTariffChangeRequest struct {
	Body PreviewTariffChangeRequestBody
}

PreviewTariffChangeRequest models a request for the 'order-preview-tariff-change' operation. See [1] for more information.

Preview TariffChange.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/order-preview-tariff-change

func (*PreviewTariffChangeRequest) BuildRequest

func (r *PreviewTariffChangeRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type PreviewTariffChangeRequestBody

type PreviewTariffChangeRequestBody struct {
	TariffChangeData *PreviewTariffChangeRequestBodyTariffChangeData `json:"tariffChangeData,omitempty"`
	TariffChangeType *PreviewTariffChangeRequestBodyTariffChangeType `json:"tariffChangeType,omitempty"`
}

PreviewTariffChangeRequestBody models the JSON body of a 'order-preview-tariff-change' request

func (*PreviewTariffChangeRequestBody) Validate

func (o *PreviewTariffChangeRequestBody) Validate() error

type PreviewTariffChangeRequestBodyTariffChangeData

type PreviewTariffChangeRequestBodyTariffChangeData struct {
	AlternativeProjectHostingTariffChange *orderv2.ProjectHostingTariffChange
	AlternativeServerTariffChange         *orderv2.ServerTariffChange
	AlternativeLeadFyndrTariffChange      *orderv2.LeadFyndrTariffChange
	AlternativeAIHostingTariffChange      *orderv2.AIHostingTariffChange
}

func (*PreviewTariffChangeRequestBodyTariffChangeData) MarshalJSON

func (*PreviewTariffChangeRequestBodyTariffChangeData) UnmarshalJSON

func (a *PreviewTariffChangeRequestBodyTariffChangeData) UnmarshalJSON(input []byte) error

func (*PreviewTariffChangeRequestBodyTariffChangeData) Validate

type PreviewTariffChangeRequestBodyTariffChangeType

type PreviewTariffChangeRequestBodyTariffChangeType string
const PreviewTariffChangeRequestBodyTariffChangeTypeAIHosting PreviewTariffChangeRequestBodyTariffChangeType = "aiHosting"
const PreviewTariffChangeRequestBodyTariffChangeTypeLeadFyndr PreviewTariffChangeRequestBodyTariffChangeType = "leadFyndr"
const PreviewTariffChangeRequestBodyTariffChangeTypeProjectHosting PreviewTariffChangeRequestBodyTariffChangeType = "projectHosting"
const PreviewTariffChangeRequestBodyTariffChangeTypeServer PreviewTariffChangeRequestBodyTariffChangeType = "server"

func (PreviewTariffChangeRequestBodyTariffChangeType) Validate

type PreviewTariffChangeResponse

type PreviewTariffChangeResponse struct {
	MachineTypePrice float64 `json:"machineTypePrice"`
	StoragePrice     float64 `json:"storagePrice"`
	TotalPrice       float64 `json:"totalPrice"`
}

func (*PreviewTariffChangeResponse) Validate

func (o *PreviewTariffChangeResponse) Validate() error

type TerminateContractItemRequest

type TerminateContractItemRequest struct {
	Body           TerminateContractItemRequestBody
	ContractID     string
	ContractItemID string
}

TerminateContractItemRequest models a request for the 'contract-terminate-contract-item' operation. See [1] for more information.

Schedule the Termination of a ContractItem.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-terminate-contract-item

func (*TerminateContractItemRequest) BuildRequest

func (r *TerminateContractItemRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type TerminateContractItemRequestBody

type TerminateContractItemRequestBody struct {
	Reason                *string    `json:"reason,omitempty"`
	TerminationTargetDate *time.Time `json:"terminationTargetDate,omitempty"`
}

TerminateContractItemRequestBody models the JSON body of a 'contract-terminate-contract-item' request

func (*TerminateContractItemRequestBody) Validate

type TerminateContractItemResponse

type TerminateContractItemResponse struct {
	ContractId            *string    `json:"contractId,omitempty"`
	ContractItemId        *string    `json:"contractItemId,omitempty"`
	Explanation           *string    `json:"explanation,omitempty"`
	Reason                *string    `json:"reason,omitempty"`
	TerminationTargetDate *time.Time `json:"terminationTargetDate,omitempty"`
}

func (*TerminateContractItemResponse) Validate

func (o *TerminateContractItemResponse) Validate() error

type TerminateContractRequest

type TerminateContractRequest struct {
	Body       TerminateContractRequestBody
	ContractID string
}

TerminateContractRequest models a request for the 'contract-terminate-contract' operation. See [1] for more information.

Schedule the Termination of a Contract.

[1]: https://developer.mittwald.de/docs/v2/reference/contract/contract-terminate-contract

func (*TerminateContractRequest) BuildRequest

func (r *TerminateContractRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type TerminateContractRequestBody

type TerminateContractRequestBody struct {
	Explanation           *string    `json:"explanation,omitempty"`
	Reason                *string    `json:"reason,omitempty"`
	TerminationTargetDate *time.Time `json:"terminationTargetDate,omitempty"`
}

TerminateContractRequestBody models the JSON body of a 'contract-terminate-contract' request

func (*TerminateContractRequestBody) Validate

func (o *TerminateContractRequestBody) Validate() error

type TerminateContractResponse

type TerminateContractResponse struct {
	ContractId                   *string    `json:"contractId,omitempty"`
	Explanation                  *string    `json:"explanation,omitempty"`
	ItemsScheduledForTermination []string   `json:"itemsScheduledForTermination,omitempty"`
	Reason                       *string    `json:"reason,omitempty"`
	TerminationTargetDate        *time.Time `json:"terminationTargetDate,omitempty"`
}

func (*TerminateContractResponse) Validate

func (o *TerminateContractResponse) Validate() error

Source Files

Jump to