Documentation
¶
Index ¶
- type Client
- type CreateFileRequest
- type DeprecatedGetFileTokenRulesRequest
- type DeprecatedGetFileTypeRulesRequest
- type DeprecatedGetFileTypeRulesRequestPathName
- type GetFileMetaRequest
- type GetFileRequest
- type GetFileRequestHeaderAccept
- type GetFileRequestHeaderContentDisposition
- type GetFileRequestQueryAccept
- type GetFileRequestQueryContentDisposition
- type GetFileUploadTokenRulesRequest
- type GetFileUploadTypeRulesRequest
- type GetFileUploadTypeRulesRequestPathFileUploadType
- type GetFileWithNameRequest
- type GetFileWithNameRequestHeaderAccept
- type GetFileWithNameRequestHeaderContentDisposition
- type GetFileWithNameRequestQueryAccept
- type GetFileWithNameRequestQueryContentDisposition
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client interface {
DeprecatedGetFileTokenRules(
ctx context.Context,
req DeprecatedGetFileTokenRulesRequest,
reqEditors ...func(req *http.Request) error,
) (*filev2.FileUploadRules, *http.Response, error)
DeprecatedGetFileTypeRules(
ctx context.Context,
req DeprecatedGetFileTypeRulesRequest,
reqEditors ...func(req *http.Request) error,
) (*filev2.FileUploadRules, *http.Response, error)
CreateFile(
ctx context.Context,
req CreateFileRequest,
reqEditors ...func(req *http.Request) error,
) (*filev2.FileMeta, *http.Response, error)
GetFileMeta(
ctx context.Context,
req GetFileMetaRequest,
reqEditors ...func(req *http.Request) error,
) (*filev2.FileMeta, *http.Response, error)
GetFileUploadTokenRules(
ctx context.Context,
req GetFileUploadTokenRulesRequest,
reqEditors ...func(req *http.Request) error,
) (*filev2.FileUploadRules, *http.Response, error)
GetFileUploadTypeRules(
ctx context.Context,
req GetFileUploadTypeRulesRequest,
reqEditors ...func(req *http.Request) error,
) (*filev2.FileUploadRules, *http.Response, error)
GetFile(
ctx context.Context,
req GetFileRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
GetFileWithName(
ctx context.Context,
req GetFileWithNameRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
}
func NewClient ¶
func NewClient(client httpclient.RequestRunner) Client
type CreateFileRequest ¶
type CreateFileRequest struct {
}
CreateFileRequest models a request for the 'file-create-file' operation. See 1 for more information.
Create a File.
func (*CreateFileRequest) BuildRequest ¶
func (r *CreateFileRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedGetFileTokenRulesRequest ¶
type DeprecatedGetFileTokenRulesRequest struct {
Token string
}
DeprecatedGetFileTokenRulesRequest models a request for the 'deprecated-file-get-file-token-rules' operation. See [1] for more information.
Get a Token's upload rules.
Deprecated by `GET /v2/file-upload-tokens/{fileUploadToken}/rules`.
[1]: https://developer.mittwald.de/docs/v2/reference/file/deprecated-file-get-file-token-rules
func (*DeprecatedGetFileTokenRulesRequest) BuildRequest ¶
func (r *DeprecatedGetFileTokenRulesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedGetFileTypeRulesRequest ¶
type DeprecatedGetFileTypeRulesRequest struct {
Name DeprecatedGetFileTypeRulesRequestPathName
}
DeprecatedGetFileTypeRulesRequest models a request for the 'deprecated-file-get-file-type-rules' operation. See [1] for more information.
Get a Type's upload rules.
Deprecated by `GET /v2/file-upload-types/{fileUploadType}/rules`.
[1]: https://developer.mittwald.de/docs/v2/reference/file/deprecated-file-get-file-type-rules
func (*DeprecatedGetFileTypeRulesRequest) BuildRequest ¶
func (r *DeprecatedGetFileTypeRulesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedGetFileTypeRulesRequestPathName ¶
type DeprecatedGetFileTypeRulesRequestPathName string
const DeprecatedGetFileTypeRulesRequestPathNameAvatar DeprecatedGetFileTypeRulesRequestPathName = "avatar"
const DeprecatedGetFileTypeRulesRequestPathNameConversation DeprecatedGetFileTypeRulesRequestPathName = "conversation"
func (DeprecatedGetFileTypeRulesRequestPathName) Validate ¶
func (e DeprecatedGetFileTypeRulesRequestPathName) Validate() error
type GetFileMetaRequest ¶
GetFileMetaRequest models a request for the 'file-get-file-meta' operation. See 1 for more information.
Get a File's meta.
func (*GetFileMetaRequest) BuildRequest ¶
func (r *GetFileMetaRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type GetFileRequest ¶
type GetFileRequest struct {
FileID string
Accept *GetFileRequestQueryAccept
ContentDisposition *GetFileRequestQueryContentDisposition
Token *string
}
GetFileRequest models a request for the 'file-get-file' operation. See 1 for more information.
Get a File.
func (*GetFileRequest) BuildRequest ¶
func (r *GetFileRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type GetFileRequestHeaderAccept ¶
type GetFileRequestHeaderAccept string
const GetFileRequestHeaderAcceptApplicationOctetStream GetFileRequestHeaderAccept = "application/octet-stream"
const GetFileRequestHeaderAcceptTextPlainBase64 GetFileRequestHeaderAccept = "text/plain;base64"
func (GetFileRequestHeaderAccept) Validate ¶
func (e GetFileRequestHeaderAccept) Validate() error
type GetFileRequestHeaderContentDisposition ¶
type GetFileRequestHeaderContentDisposition string
const GetFileRequestHeaderContentDispositionAttachment GetFileRequestHeaderContentDisposition = "attachment"
const GetFileRequestHeaderContentDispositionInline GetFileRequestHeaderContentDisposition = "inline"
func (GetFileRequestHeaderContentDisposition) Validate ¶
func (e GetFileRequestHeaderContentDisposition) Validate() error
type GetFileRequestQueryAccept ¶
type GetFileRequestQueryAccept string
const GetFileRequestQueryAcceptApplicationOctetStream GetFileRequestQueryAccept = "application/octet-stream"
const GetFileRequestQueryAcceptTextPlainBase64 GetFileRequestQueryAccept = "text/plain;base64"
func (GetFileRequestQueryAccept) Validate ¶
func (e GetFileRequestQueryAccept) Validate() error
type GetFileRequestQueryContentDisposition ¶
type GetFileRequestQueryContentDisposition string
const GetFileRequestQueryContentDispositionAttachment GetFileRequestQueryContentDisposition = "attachment"
const GetFileRequestQueryContentDispositionInline GetFileRequestQueryContentDisposition = "inline"
func (GetFileRequestQueryContentDisposition) Validate ¶
func (e GetFileRequestQueryContentDisposition) Validate() error
type GetFileUploadTokenRulesRequest ¶
type GetFileUploadTokenRulesRequest struct {
FileUploadToken string
}
GetFileUploadTokenRulesRequest models a request for the 'file-get-file-upload-token-rules' operation. See [1] for more information.
Get a FileUploadToken's rules.
[1]: https://developer.mittwald.de/docs/v2/reference/file/file-get-file-upload-token-rules
func (*GetFileUploadTokenRulesRequest) BuildRequest ¶
func (r *GetFileUploadTokenRulesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type GetFileUploadTypeRulesRequest ¶
type GetFileUploadTypeRulesRequest struct {
FileUploadType GetFileUploadTypeRulesRequestPathFileUploadType
}
GetFileUploadTypeRulesRequest models a request for the 'file-get-file-upload-type-rules' operation. See [1] for more information.
Get a FileUploadType's rules.
[1]: https://developer.mittwald.de/docs/v2/reference/file/file-get-file-upload-type-rules
func (*GetFileUploadTypeRulesRequest) BuildRequest ¶
func (r *GetFileUploadTypeRulesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type GetFileUploadTypeRulesRequestPathFileUploadType ¶
type GetFileUploadTypeRulesRequestPathFileUploadType string
const GetFileUploadTypeRulesRequestPathFileUploadTypeAnchorIcon GetFileUploadTypeRulesRequestPathFileUploadType = "anchorIcon"
const GetFileUploadTypeRulesRequestPathFileUploadTypeAvatar GetFileUploadTypeRulesRequestPathFileUploadType = "avatar"
const GetFileUploadTypeRulesRequestPathFileUploadTypeConversation GetFileUploadTypeRulesRequestPathFileUploadType = "conversation"
const GetFileUploadTypeRulesRequestPathFileUploadTypeExtensionAssetImage GetFileUploadTypeRulesRequestPathFileUploadType = "extensionAssetImage"
const GetFileUploadTypeRulesRequestPathFileUploadTypeExtensionAssetVideo GetFileUploadTypeRulesRequestPathFileUploadType = "extensionAssetVideo"
func (GetFileUploadTypeRulesRequestPathFileUploadType) Validate ¶
func (e GetFileUploadTypeRulesRequestPathFileUploadType) Validate() error
type GetFileWithNameRequest ¶
type GetFileWithNameRequest struct {
FileID string
FileName string
Accept *GetFileWithNameRequestQueryAccept
ContentDisposition *GetFileWithNameRequestQueryContentDisposition
Token *string
}
GetFileWithNameRequest models a request for the 'file-get-file-with-name' operation. See [1] for more information.
Get a File with user-friendly url.
[1]: https://developer.mittwald.de/docs/v2/reference/file/file-get-file-with-name
func (*GetFileWithNameRequest) BuildRequest ¶
func (r *GetFileWithNameRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type GetFileWithNameRequestHeaderAccept ¶
type GetFileWithNameRequestHeaderAccept string
const GetFileWithNameRequestHeaderAcceptApplicationOctetStream GetFileWithNameRequestHeaderAccept = "application/octet-stream"
const GetFileWithNameRequestHeaderAcceptTextPlainBase64 GetFileWithNameRequestHeaderAccept = "text/plain;base64"
func (GetFileWithNameRequestHeaderAccept) Validate ¶
func (e GetFileWithNameRequestHeaderAccept) Validate() error
type GetFileWithNameRequestHeaderContentDisposition ¶
type GetFileWithNameRequestHeaderContentDisposition string
const GetFileWithNameRequestHeaderContentDispositionAttachment GetFileWithNameRequestHeaderContentDisposition = "attachment"
const GetFileWithNameRequestHeaderContentDispositionInline GetFileWithNameRequestHeaderContentDisposition = "inline"
func (GetFileWithNameRequestHeaderContentDisposition) Validate ¶
func (e GetFileWithNameRequestHeaderContentDisposition) Validate() error
type GetFileWithNameRequestQueryAccept ¶
type GetFileWithNameRequestQueryAccept string
const GetFileWithNameRequestQueryAcceptApplicationOctetStream GetFileWithNameRequestQueryAccept = "application/octet-stream"
const GetFileWithNameRequestQueryAcceptTextPlainBase64 GetFileWithNameRequestQueryAccept = "text/plain;base64"
func (GetFileWithNameRequestQueryAccept) Validate ¶
func (e GetFileWithNameRequestQueryAccept) Validate() error
type GetFileWithNameRequestQueryContentDisposition ¶
type GetFileWithNameRequestQueryContentDisposition string
const GetFileWithNameRequestQueryContentDispositionAttachment GetFileWithNameRequestQueryContentDisposition = "attachment"
const GetFileWithNameRequestQueryContentDispositionInline GetFileWithNameRequestQueryContentDisposition = "inline"
func (GetFileWithNameRequestQueryContentDisposition) Validate ¶
func (e GetFileWithNameRequestQueryContentDisposition) Validate() error
Source Files
¶
- client.go
- createfile_request.go
- deprecatedgetfiletokenrules_request.go
- deprecatedgetfiletyperules_request.go
- deprecatedgetfiletyperules_request_path_name.go
- getfile_request.go
- getfile_request_header_accept.go
- getfile_request_header_content-disposition.go
- getfile_request_query_accept.go
- getfile_request_query_content-disposition.go
- getfilemeta_request.go
- getfileuploadtokenrules_request.go
- getfileuploadtyperules_request.go
- getfileuploadtyperules_request_path_fileuploadtype.go
- getfilewithname_request.go
- getfilewithname_request_header_accept.go
- getfilewithname_request_header_content-disposition.go
- getfilewithname_request_query_accept.go
- getfilewithname_request_query_content-disposition.go