miscclientv2

package
v0.2.187 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client interface {
	MiscellaneousListTimeZones(
		ctx context.Context,
		req MiscellaneousListTimeZonesRequest,
		reqEditors ...func(req *http.Request) error,
	) (*[]string, *http.Response, error)
	ServicetokenAuthenticateService(
		ctx context.Context,
		req ServicetokenAuthenticateServiceRequest,
		reqEditors ...func(req *http.Request) error,
	) (*ServicetokenAuthenticateServiceResponse, *http.Response, error)
	VerificationDetectPhishingEmail(
		ctx context.Context,
		req VerificationDetectPhishingEmailRequest,
		reqEditors ...func(req *http.Request) error,
	) (*verificationv2.EmailDetectPhishingMailResponse, *http.Response, error)
	VerificationVerifyAddress(
		ctx context.Context,
		req VerificationVerifyAddressRequest,
		reqEditors ...func(req *http.Request) error,
	) (*VerificationVerifyAddressResponse, *http.Response, error)
	VerificationVerifyCompany(
		ctx context.Context,
		req VerificationVerifyCompanyRequest,
		reqEditors ...func(req *http.Request) error,
	) (*VerificationVerifyCompanyResponse, *http.Response, error)
}

func NewClient

func NewClient(client httpclient.RequestRunner) Client

type MiscellaneousListTimeZonesRequest added in v0.2.141

type MiscellaneousListTimeZonesRequest struct {
}

MiscellaneousListTimeZonesRequest models a request for the 'miscellaneous-list-time-zones' operation. See [1] for more information.

List valid time zones.

[1]: https://developer.mittwald.de/docs/v2/reference/misc/miscellaneous-list-time-zones

func (*MiscellaneousListTimeZonesRequest) BuildRequest added in v0.2.141

func (r *MiscellaneousListTimeZonesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ServicetokenAuthenticateServiceRequest

type ServicetokenAuthenticateServiceRequest struct {
	Body        ServicetokenAuthenticateServiceRequestBody
	AccessKeyID string
}

ServicetokenAuthenticateServiceRequest models a request for the 'servicetoken-authenticate-service' operation. See [1] for more information.

Obtain a service token.

[1]: https://developer.mittwald.de/docs/v2/reference/misc/servicetoken-authenticate-service

func (*ServicetokenAuthenticateServiceRequest) BuildRequest

func (r *ServicetokenAuthenticateServiceRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type ServicetokenAuthenticateServiceRequestBody

type ServicetokenAuthenticateServiceRequestBody struct {
	SecretAccessKey string `json:"secretAccessKey"`
}

ServicetokenAuthenticateServiceRequestBody models the JSON body of a 'servicetoken-authenticate-service' request

func (*ServicetokenAuthenticateServiceRequestBody) Validate

type ServicetokenAuthenticateServiceResponse

type ServicetokenAuthenticateServiceResponse struct {
	AccessToken ServicetokenAuthenticateServiceResponseAccessToken `json:"accessToken"`
}

func (*ServicetokenAuthenticateServiceResponse) Validate

type ServicetokenAuthenticateServiceResponseAccessToken

type ServicetokenAuthenticateServiceResponseAccessToken struct {
	Id          string                                                      `json:"id"`
	JwtClaims   ServicetokenAuthenticateServiceResponseAccessTokenJwtClaims `json:"jwtClaims"`
	PublicToken string                                                      `json:"publicToken"`
}

func (*ServicetokenAuthenticateServiceResponseAccessToken) Validate

type ServicetokenAuthenticateServiceResponseAccessTokenJwtClaims

type ServicetokenAuthenticateServiceResponseAccessTokenJwtClaims struct {
	Exp string `json:"exp"`
	Iat string `json:"iat"`
	Iss string `json:"iss"`
	Sub string `json:"sub"`
}

func (*ServicetokenAuthenticateServiceResponseAccessTokenJwtClaims) Validate

type VerificationDetectPhishingEmailRequest added in v0.2.69

type VerificationDetectPhishingEmailRequest struct {
}

VerificationDetectPhishingEmailRequest models a request for the 'verification-detect-phishing-email' operation. See [1] for more information.

Check if an email is from mittwald.

Parses the eml-file of an email to check if it is a phishing mail or a valid email from mittwald. In some cases we can't confirm the validity of an email.

[1]: https://developer.mittwald.de/docs/v2/reference/misc/verification-detect-phishing-email

func (*VerificationDetectPhishingEmailRequest) BuildRequest added in v0.2.69

func (r *VerificationDetectPhishingEmailRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type VerificationVerifyAddressRequest

type VerificationVerifyAddressRequest struct {
	Body VerificationVerifyAddressRequestBody
}

VerificationVerifyAddressRequest models a request for the 'verification-verify-address' operation. See [1] for more information.

Check if an address exists.

[1]: https://developer.mittwald.de/docs/v2/reference/misc/verification-verify-address

func (*VerificationVerifyAddressRequest) BuildRequest

func (r *VerificationVerifyAddressRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type VerificationVerifyAddressRequestBody

type VerificationVerifyAddressRequestBody struct {
	City    string `json:"city"`
	Country string `json:"country"`
	Street  string `json:"street"`
	Zip     string `json:"zip"`
}

VerificationVerifyAddressRequestBody models the JSON body of a 'verification-verify-address' request

func (*VerificationVerifyAddressRequestBody) Validate

type VerificationVerifyAddressResponse

type VerificationVerifyAddressResponse struct {
	Exists bool `json:"exists"`
}

func (*VerificationVerifyAddressResponse) Validate

type VerificationVerifyCompanyRequest

type VerificationVerifyCompanyRequest struct {
	Body VerificationVerifyCompanyRequestBody
}

VerificationVerifyCompanyRequest models a request for the 'verification-verify-company' operation. See [1] for more information.

Check if a company exists.

Only companies registered in the German company register are currently supported.

[1]: https://developer.mittwald.de/docs/v2/reference/misc/verification-verify-company

func (*VerificationVerifyCompanyRequest) BuildRequest

func (r *VerificationVerifyCompanyRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type VerificationVerifyCompanyRequestBody

type VerificationVerifyCompanyRequestBody struct {
	Name string `json:"name"`
}

VerificationVerifyCompanyRequestBody models the JSON body of a 'verification-verify-company' request

func (*VerificationVerifyCompanyRequestBody) Validate

type VerificationVerifyCompanyResponse

type VerificationVerifyCompanyResponse struct {
	Exists bool `json:"exists"`
}

func (*VerificationVerifyCompanyResponse) Validate

Jump to