relocationclientv2

package
v0.2.196 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 21, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client interface {
	CreateLegacyTariffChange(
		ctx context.Context,
		req CreateLegacyTariffChangeRequest,
		reqEditors ...func(req *http.Request) error,
	) (*CreateLegacyTariffChangeResponse, *http.Response, error)
	CreateRelocation(
		ctx context.Context,
		req CreateRelocationRequest,
		reqEditors ...func(req *http.Request) error,
	) (*http.Response, error)
}

func NewClient

func NewClient(client httpclient.RequestRunner) Client

type CreateLegacyTariffChangeRequest

type CreateLegacyTariffChangeRequest struct {
	Body CreateLegacyTariffChangeRequestBody
}

CreateLegacyTariffChangeRequest models a request for the 'relocation-create-legacy-tariff-change' operation. See [1] for more information.

Register a tariff change for a legacy tariff.

[1]: https://developer.mittwald.de/docs/v2/reference/relocation/relocation-create-legacy-tariff-change

func (*CreateLegacyTariffChangeRequest) BuildRequest

func (r *CreateLegacyTariffChangeRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type CreateLegacyTariffChangeRequestBody

type CreateLegacyTariffChangeRequestBody struct {
	PAccount     string `json:"pAccount"`
	TargetTariff string `json:"targetTariff"`
}

CreateLegacyTariffChangeRequestBody models the JSON body of a 'relocation-create-legacy-tariff-change' request

func (*CreateLegacyTariffChangeRequestBody) Validate

type CreateLegacyTariffChangeResponse

type CreateLegacyTariffChangeResponse struct {
	MessageId string `json:"messageId"`
}

func (*CreateLegacyTariffChangeResponse) Validate

type CreateRelocationRequest

type CreateRelocationRequest struct {
	Body CreateRelocationRequestBody
}

CreateRelocationRequest models a request for the 'relocation-create-relocation' operation. See [1] for more information.

Relocate an external Project to mittwald.

Give mittwald access to your Provider and let them move your Project to mittwald.

[1]: https://developer.mittwald.de/docs/v2/reference/relocation/relocation-create-relocation

func (*CreateRelocationRequest) BuildRequest

func (r *CreateRelocationRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)

BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.

type CreateRelocationRequestBody

type CreateRelocationRequestBody struct {
	AdditionalServices  CreateRelocationRequestBodyAdditionalServices `json:"additionalServices"`
	AllDomains          *bool                                         `json:"allDomains,omitempty"`
	AllowPasswordChange bool                                          `json:"allowPasswordChange"`
	ArticleType         CreateRelocationRequestBodyArticleType        `json:"articleType"`
	Contact             CreateRelocationRequestBodyContact            `json:"contact"`
	Domains             []directusv2.Domain                           `json:"domains,omitempty"`
	EmailInboxes        []directusv2.EmailInbox                       `json:"emailInboxes,omitempty"`
	Notes               *string                                       `json:"notes,omitempty"`
	Prices              CreateRelocationRequestBodyPrices             `json:"prices"`
	Provider            CreateRelocationRequestBodyProvider           `json:"provider"`
	Target              CreateRelocationRequestBodyTarget             `json:"target"`
	UserId              *CreateRelocationRequestBodyUserID            `json:"userId,omitempty"`
}

CreateRelocationRequestBody models the JSON body of a 'relocation-create-relocation' request

func (*CreateRelocationRequestBody) Validate

func (o *CreateRelocationRequestBody) Validate() error

type CreateRelocationRequestBodyAdditionalServices

type CreateRelocationRequestBodyAdditionalServices struct {
	DataCompare CreateRelocationRequestBodyAdditionalServicesDataCompare `json:"dataCompare"`
}

func (*CreateRelocationRequestBodyAdditionalServices) Validate

type CreateRelocationRequestBodyAdditionalServicesDataCompare

type CreateRelocationRequestBodyAdditionalServicesDataCompare string
const CreateRelocationRequestBodyAdditionalServicesDataCompareAdditionalCompare CreateRelocationRequestBodyAdditionalServicesDataCompare = "additionalCompare"
const CreateRelocationRequestBodyAdditionalServicesDataCompareDefault CreateRelocationRequestBodyAdditionalServicesDataCompare = "default"

func (CreateRelocationRequestBodyAdditionalServicesDataCompare) Validate

type CreateRelocationRequestBodyArticleType

type CreateRelocationRequestBodyArticleType string

Type of the article you want to relocate.

const CreateRelocationRequestBodyArticleTypeCmsHosting CreateRelocationRequestBodyArticleType = "cms-hosting"
const CreateRelocationRequestBodyArticleTypeCmsHostingExpress CreateRelocationRequestBodyArticleType = "cms-hosting-express"
const CreateRelocationRequestBodyArticleTypeOnlineshop CreateRelocationRequestBodyArticleType = "onlineshop"
const CreateRelocationRequestBodyArticleTypeOnlineshopExpress CreateRelocationRequestBodyArticleType = "onlineshop-express"

func (CreateRelocationRequestBodyArticleType) Validate

type CreateRelocationRequestBodyContact

type CreateRelocationRequestBodyContact struct {
	Email       string  `json:"email"`
	FirstName   string  `json:"firstName"`
	LastName    string  `json:"lastName"`
	PhoneNumber *string `json:"phoneNumber,omitempty"`
}

func (*CreateRelocationRequestBodyContact) Validate

type CreateRelocationRequestBodyPrices

type CreateRelocationRequestBodyPrices struct {
	Positions []CreateRelocationRequestBodyPricesPositionsItem `json:"positions"`
	Total     float64                                          `json:"total"`
}

func (*CreateRelocationRequestBodyPrices) Validate

type CreateRelocationRequestBodyPricesPositionsItem

type CreateRelocationRequestBodyPricesPositionsItem struct {
	Name  string  `json:"name"`
	Price float64 `json:"price"`
}

func (*CreateRelocationRequestBodyPricesPositionsItem) Validate

type CreateRelocationRequestBodyProvider

type CreateRelocationRequestBodyProvider struct {
	LoginUrl      string                                  `json:"loginUrl"`
	Name          CreateRelocationRequestBodyProviderName `json:"name"`
	Password      string                                  `json:"password"`
	SourceAccount string                                  `json:"sourceAccount"`
	UserName      string                                  `json:"userName"`
}

func (*CreateRelocationRequestBodyProvider) Validate

type CreateRelocationRequestBodyProviderName

type CreateRelocationRequestBodyProviderName struct {
	AlternativeCreateRelocationRequestBodyProviderNameAlternative1 *string
	AlternativeCreateRelocationRequestBodyProviderNameAlternative2 *CreateRelocationRequestBodyProviderNameAlternative2
}

func (*CreateRelocationRequestBodyProviderName) MarshalJSON

func (a *CreateRelocationRequestBodyProviderName) MarshalJSON() ([]byte, error)

func (CreateRelocationRequestBodyProviderName) String added in v0.2.31

func (*CreateRelocationRequestBodyProviderName) UnmarshalJSON

func (a *CreateRelocationRequestBodyProviderName) UnmarshalJSON(input []byte) error

func (*CreateRelocationRequestBodyProviderName) Validate

type CreateRelocationRequestBodyProviderNameAlternative2

type CreateRelocationRequestBodyProviderNameAlternative2 string
const CreateRelocationRequestBodyProviderNameAlternative21Und1 CreateRelocationRequestBodyProviderNameAlternative2 = "1und1"
const CreateRelocationRequestBodyProviderNameAlternative2Strato CreateRelocationRequestBodyProviderNameAlternative2 = "strato"

func (CreateRelocationRequestBodyProviderNameAlternative2) Validate

type CreateRelocationRequestBodyTarget

type CreateRelocationRequestBodyTarget struct {
	Organisation string                                   `json:"organisation"`
	Product      CreateRelocationRequestBodyTargetProduct `json:"product"`
	ProjectName  string                                   `json:"projectName"`
	System       CreateRelocationRequestBodyTargetSystem  `json:"system"`
}

func (*CreateRelocationRequestBodyTarget) Validate

type CreateRelocationRequestBodyTargetProduct

type CreateRelocationRequestBodyTargetProduct struct {
	AlternativeCreateRelocationRequestBodyTargetProductAlternative1 *string
	AlternativeCreateRelocationRequestBodyTargetProductAlternative2 *CreateRelocationRequestBodyTargetProductAlternative2
}

func (*CreateRelocationRequestBodyTargetProduct) MarshalJSON

func (a *CreateRelocationRequestBodyTargetProduct) MarshalJSON() ([]byte, error)

func (CreateRelocationRequestBodyTargetProduct) String added in v0.2.31

func (*CreateRelocationRequestBodyTargetProduct) UnmarshalJSON

func (a *CreateRelocationRequestBodyTargetProduct) UnmarshalJSON(input []byte) error

func (*CreateRelocationRequestBodyTargetProduct) Validate

type CreateRelocationRequestBodyTargetProductAlternative2

type CreateRelocationRequestBodyTargetProductAlternative2 string
const CreateRelocationRequestBodyTargetProductAlternative2AgenturServer CreateRelocationRequestBodyTargetProductAlternative2 = "Agentur-Server"
const CreateRelocationRequestBodyTargetProductAlternative2CMSHosting CreateRelocationRequestBodyTargetProductAlternative2 = "CMS-Hosting"
const CreateRelocationRequestBodyTargetProductAlternative2ProSpace CreateRelocationRequestBodyTargetProductAlternative2 = "proSpace"
const CreateRelocationRequestBodyTargetProductAlternative2ShopHosting CreateRelocationRequestBodyTargetProductAlternative2 = "Shop-Hosting"
const CreateRelocationRequestBodyTargetProductAlternative2SpaceServer CreateRelocationRequestBodyTargetProductAlternative2 = "Space-Server"

func (CreateRelocationRequestBodyTargetProductAlternative2) Validate

type CreateRelocationRequestBodyTargetSystem

type CreateRelocationRequestBodyTargetSystem string

Which mittwald system does the targetProject use?

const CreateRelocationRequestBodyTargetSystemKc CreateRelocationRequestBodyTargetSystem = "kc"
const CreateRelocationRequestBodyTargetSystemMstudio CreateRelocationRequestBodyTargetSystem = "mstudio"

func (CreateRelocationRequestBodyTargetSystem) Validate

type CreateRelocationRequestBodyUserID

type CreateRelocationRequestBodyUserID struct {
	AlternativeCreateRelocationRequestBodyUserIDAlternative1 *string
	AlternativeCreateRelocationRequestBodyUserIDAlternative2 *string
}

func (*CreateRelocationRequestBodyUserID) MarshalJSON

func (a *CreateRelocationRequestBodyUserID) MarshalJSON() ([]byte, error)

func (CreateRelocationRequestBodyUserID) String added in v0.2.31

func (*CreateRelocationRequestBodyUserID) UnmarshalJSON

func (a *CreateRelocationRequestBodyUserID) UnmarshalJSON(input []byte) error

func (*CreateRelocationRequestBodyUserID) Validate

Jump to