stracev2

package
v0.2.187 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Data

type Data struct {
	ActualUrl       string                  `json:"actualUrl"`
	DbQueries       []DataDbQueriesItem     `json:"dbQueries"`
	DbStats         Statistics              `json:"dbStats"`
	FileOps         []DataFileOpsItem       `json:"fileOps"`
	FileOpsStats    Statistics              `json:"fileOpsStats"`
	MiscStats       Statistics              `json:"miscStats"`
	NetworkingOps   []DataNetworkingOpsItem `json:"networkingOps"`
	NetworkingStats Statistics              `json:"networkingStats"`
	SlowdownFactor  float64                 `json:"slowdownFactor"`
	TtfbMs          int64                   `json:"ttfbMs"`
}

func (*Data) Validate

func (o *Data) Validate() error

type DataDbQueriesItem

type DataDbQueriesItem struct {
	Query     string                     `json:"query"`
	Stats     Statistics                 `json:"stats"`
	WarnLevel DataDbQueriesItemWarnLevel `json:"warnLevel"`
}

func (*DataDbQueriesItem) Validate

func (o *DataDbQueriesItem) Validate() error

type DataDbQueriesItemWarnLevel

type DataDbQueriesItemWarnLevel string

Alerts when the time, syscall count or occurrence count of this group are abnormal.

const DataDbQueriesItemWarnLevelNO DataDbQueriesItemWarnLevel = "NO"
const DataDbQueriesItemWarnLevelSEVERE DataDbQueriesItemWarnLevel = "SEVERE"
const DataDbQueriesItemWarnLevelWARN DataDbQueriesItemWarnLevel = "WARN"

func (DataDbQueriesItemWarnLevel) Validate

func (e DataDbQueriesItemWarnLevel) Validate() error

type DataFileOpsItem

type DataFileOpsItem struct {
	Filename  *string                  `json:"filename,omitempty"`
	Filepath  *string                  `json:"filepath,omitempty"`
	Stats     Statistics               `json:"stats"`
	WarnLevel DataFileOpsItemWarnLevel `json:"warnLevel"`
}

func (*DataFileOpsItem) Validate

func (o *DataFileOpsItem) Validate() error

type DataFileOpsItemWarnLevel

type DataFileOpsItemWarnLevel string

Alerts when the time, syscall count or occurrence count of this group are abnormal.

const DataFileOpsItemWarnLevelNO DataFileOpsItemWarnLevel = "NO"
const DataFileOpsItemWarnLevelSEVERE DataFileOpsItemWarnLevel = "SEVERE"
const DataFileOpsItemWarnLevelWARN DataFileOpsItemWarnLevel = "WARN"

func (DataFileOpsItemWarnLevel) Validate

func (e DataFileOpsItemWarnLevel) Validate() error

type DataNetworkingOpsItem

type DataNetworkingOpsItem struct {
	ConnectionType DataNetworkingOpsItemConnectionType `json:"connectionType"`
	Description    string                              `json:"description"`
	Ip             string                              `json:"ip"`
	Port           int64                               `json:"port"`
	Stats          Statistics                          `json:"stats"`
	WarnLevel      DataNetworkingOpsItemWarnLevel      `json:"warnLevel"`
}

func (*DataNetworkingOpsItem) Validate

func (o *DataNetworkingOpsItem) Validate() error

type DataNetworkingOpsItemConnectionType

type DataNetworkingOpsItemConnectionType string
const DataNetworkingOpsItemConnectionTypeEXTERNAL DataNetworkingOpsItemConnectionType = "EXTERNAL"
const DataNetworkingOpsItemConnectionTypePRIVATE DataNetworkingOpsItemConnectionType = "PRIVATE"
const DataNetworkingOpsItemConnectionTypeUNKNOWN DataNetworkingOpsItemConnectionType = "UNKNOWN"

func (DataNetworkingOpsItemConnectionType) Validate

type DataNetworkingOpsItemWarnLevel

type DataNetworkingOpsItemWarnLevel string

Alerts when the time, syscall count or occurrence count of this group are abnormal.

const DataNetworkingOpsItemWarnLevelNO DataNetworkingOpsItemWarnLevel = "NO"
const DataNetworkingOpsItemWarnLevelSEVERE DataNetworkingOpsItemWarnLevel = "SEVERE"
const DataNetworkingOpsItemWarnLevelWARN DataNetworkingOpsItemWarnLevel = "WARN"

func (DataNetworkingOpsItemWarnLevel) Validate

type Error

type Error struct {
	ErrorMessage string `json:"errorMessage"`
}

func (*Error) Validate

func (o *Error) Validate() error

type Statistics

type Statistics struct {
	KernelMs     float64 `json:"kernelMs"`
	Occurrences  int64   `json:"occurrences"`
	SyscallCount int64   `json:"syscallCount"`
	UserspaceMs  float64 `json:"userspaceMs"`
}

func (*Statistics) Validate

func (o *Statistics) Validate() error

Jump to