Documentation
¶
Index ¶
- type Client
- type CreateDeliveryboxRequest
- type CreateDeliveryboxRequestBody
- type CreateDeliveryboxResponse
- type CreateMailAddressRequest
- type CreateMailAddressRequestBody
- type CreateMailAddressResponse
- type DeleteDeliveryBoxRequest
- type DeleteMailAddressRequest
- type DeprecatedMailaddressUpdateAddressRequest
- type DeprecatedMailaddressUpdateAddressRequestBody
- type DeprecatedProjectsettingUpdateBlacklistRequest
- type DeprecatedProjectsettingUpdateBlacklistRequestBody
- type DeprecatedProjectsettingUpdateWhitelistRequest
- type DeprecatedProjectsettingUpdateWhitelistRequestBody
- type DeprecatedUpdateDescriptionRequest
- type DeprecatedUpdateDescriptionRequestBody
- type DeprecatedUpdateMailAddressAutoresponderRequest
- type DeprecatedUpdateMailAddressAutoresponderRequestBody
- type DeprecatedUpdateMailAddressAutoresponderRequestBodyAutoResponder
- type DeprecatedUpdateMailAddressCatchallRequest
- type DeprecatedUpdateMailAddressCatchallRequestBody
- type DeprecatedUpdateMailAddressForwardAddressesRequest
- type DeprecatedUpdateMailAddressForwardAddressesRequestBody
- type DeprecatedUpdateMailAddressPasswordRequest
- type DeprecatedUpdateMailAddressPasswordRequestBody
- type DeprecatedUpdateMailAddressQuotaRequest
- type DeprecatedUpdateMailAddressQuotaRequestBody
- type DeprecatedUpdateMailAddressSpamProtectionRequest
- type DeprecatedUpdateMailAddressSpamProtectionRequestBody
- type DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtection
- type DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder
- type DeprecatedUpdatePasswordRequest
- type DeprecatedUpdatePasswordRequestBody
- type DeprecatedUpdateProjectMailSettingRequest
- type DeprecatedUpdateProjectMailSettingRequestBody
- type DeprecatedUpdateProjectMailSettingRequestBodyAlternative1
- type DeprecatedUpdateProjectMailSettingRequestBodyAlternative2
- type DeprecatedUpdateProjectMailSettingRequestPathSetting
- type GetDeliveryBoxRequest
- type GetMailAddressRequest
- type ListDeliveryBoxesRequest
- type ListMailAddressesRequest
- type ListMailAddressesRequestQueryOrderItem
- type ListMailAddressesRequestQuerySortItem
- type ListProjectMailSettingsRequest
- type ListProjectMailSettingsResponse
- type UpdateDeliveryBoxDescriptionRequest
- type UpdateDeliveryBoxDescriptionRequestBody
- type UpdateDeliveryBoxPasswordRequest
- type UpdateDeliveryBoxPasswordRequestBody
- type UpdateMailAddressAddressRequest
- type UpdateMailAddressAddressRequestBody
- type UpdateMailAddressAutoresponderRequest
- type UpdateMailAddressAutoresponderRequestBody
- type UpdateMailAddressAutoresponderRequestBodyAutoResponder
- type UpdateMailAddressCatchAllRequest
- type UpdateMailAddressCatchAllRequestBody
- type UpdateMailAddressForwardAddressesRequest
- type UpdateMailAddressForwardAddressesRequestBody
- type UpdateMailAddressPasswordRequest
- type UpdateMailAddressPasswordRequestBody
- type UpdateMailAddressQuotaRequest
- type UpdateMailAddressQuotaRequestBody
- type UpdateMailAddressSpamProtectionRequest
- type UpdateMailAddressSpamProtectionRequestBody
- type UpdateMailAddressSpamProtectionRequestBodySpamProtection
- type UpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder
- type UpdateProjectMailSettingRequest
- type UpdateProjectMailSettingRequestBody
- type UpdateProjectMailSettingRequestBodyAlternative1
- type UpdateProjectMailSettingRequestBodyAlternative2
- type UpdateProjectMailSettingRequestPathMailSetting
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client interface {
DeprecatedUpdateDescription(
ctx context.Context,
req DeprecatedUpdateDescriptionRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedUpdatePassword(
ctx context.Context,
req DeprecatedUpdatePasswordRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedMailaddressUpdateAddress(
ctx context.Context,
req DeprecatedMailaddressUpdateAddressRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedProjectsettingUpdateBlacklist(
ctx context.Context,
req DeprecatedProjectsettingUpdateBlacklistRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedProjectsettingUpdateWhitelist(
ctx context.Context,
req DeprecatedProjectsettingUpdateWhitelistRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedUpdateMailAddressAutoresponder(
ctx context.Context,
req DeprecatedUpdateMailAddressAutoresponderRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
UpdateMailAddressAutoresponder(
ctx context.Context,
req UpdateMailAddressAutoresponderRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedUpdateMailAddressCatchall(
ctx context.Context,
req DeprecatedUpdateMailAddressCatchallRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedUpdateMailAddressForwardAddresses(
ctx context.Context,
req DeprecatedUpdateMailAddressForwardAddressesRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
UpdateMailAddressForwardAddresses(
ctx context.Context,
req UpdateMailAddressForwardAddressesRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedUpdateMailAddressPassword(
ctx context.Context,
req DeprecatedUpdateMailAddressPasswordRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
UpdateMailAddressPassword(
ctx context.Context,
req UpdateMailAddressPasswordRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedUpdateMailAddressQuota(
ctx context.Context,
req DeprecatedUpdateMailAddressQuotaRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
UpdateMailAddressQuota(
ctx context.Context,
req UpdateMailAddressQuotaRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedUpdateMailAddressSpamProtection(
ctx context.Context,
req DeprecatedUpdateMailAddressSpamProtectionRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
UpdateMailAddressSpamProtection(
ctx context.Context,
req UpdateMailAddressSpamProtectionRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
DeprecatedUpdateProjectMailSetting(
ctx context.Context,
req DeprecatedUpdateProjectMailSettingRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
ListDeliveryBoxes(
ctx context.Context,
req ListDeliveryBoxesRequest,
reqEditors ...func(req *http.Request) error,
) (*[]mailv2.Deliverybox, *http.Response, error)
CreateDeliverybox(
ctx context.Context,
req CreateDeliveryboxRequest,
reqEditors ...func(req *http.Request) error,
) (*CreateDeliveryboxResponse, *http.Response, error)
ListMailAddresses(
ctx context.Context,
req ListMailAddressesRequest,
reqEditors ...func(req *http.Request) error,
) (*[]mailv2.MailAddress, *http.Response, error)
CreateMailAddress(
ctx context.Context,
req CreateMailAddressRequest,
reqEditors ...func(req *http.Request) error,
) (*CreateMailAddressResponse, *http.Response, error)
GetDeliveryBox(
ctx context.Context,
req GetDeliveryBoxRequest,
reqEditors ...func(req *http.Request) error,
) (*mailv2.Deliverybox, *http.Response, error)
DeleteDeliveryBox(
ctx context.Context,
req DeleteDeliveryBoxRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
GetMailAddress(
ctx context.Context,
req GetMailAddressRequest,
reqEditors ...func(req *http.Request) error,
) (*mailv2.MailAddress, *http.Response, error)
DeleteMailAddress(
ctx context.Context,
req DeleteMailAddressRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
ListProjectMailSettings(
ctx context.Context,
req ListProjectMailSettingsRequest,
reqEditors ...func(req *http.Request) error,
) (*ListProjectMailSettingsResponse, *http.Response, error)
UpdateDeliveryBoxDescription(
ctx context.Context,
req UpdateDeliveryBoxDescriptionRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
UpdateDeliveryBoxPassword(
ctx context.Context,
req UpdateDeliveryBoxPasswordRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
UpdateMailAddressAddress(
ctx context.Context,
req UpdateMailAddressAddressRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
UpdateMailAddressCatchAll(
ctx context.Context,
req UpdateMailAddressCatchAllRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
UpdateProjectMailSetting(
ctx context.Context,
req UpdateProjectMailSettingRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
}
func NewClient ¶
func NewClient(client httpclient.RequestRunner) Client
type CreateDeliveryboxRequest ¶
type CreateDeliveryboxRequest struct {
Body CreateDeliveryboxRequestBody
ProjectID string
}
CreateDeliveryboxRequest models a request for the 'mail-create-deliverybox' operation. See [1] for more information.
Create a DeliveryBox.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-create-deliverybox
func (*CreateDeliveryboxRequest) BuildRequest ¶
func (r *CreateDeliveryboxRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type CreateDeliveryboxRequestBody ¶
type CreateDeliveryboxRequestBody struct {
Description string `json:"description"`
Password string `json:"password"`
}
CreateDeliveryboxRequestBody models the JSON body of a 'mail-create-deliverybox' request
func (*CreateDeliveryboxRequestBody) Validate ¶
func (o *CreateDeliveryboxRequestBody) Validate() error
type CreateDeliveryboxResponse ¶
type CreateDeliveryboxResponse struct {
Id string `json:"id"`
}
func (*CreateDeliveryboxResponse) Validate ¶
func (o *CreateDeliveryboxResponse) Validate() error
type CreateMailAddressRequest ¶
type CreateMailAddressRequest struct {
Body CreateMailAddressRequestBody
ProjectID string
}
CreateMailAddressRequest models a request for the 'mail-create-mail-address' operation. See [1] for more information.
Create a MailAddress.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-create-mail-address
func (*CreateMailAddressRequest) BuildRequest ¶
func (r *CreateMailAddressRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type CreateMailAddressRequestBody ¶
type CreateMailAddressRequestBody struct {
AlternativeCreateForwardAddress *mailv2.CreateForwardAddress
AlternativeCreateMailAddress *mailv2.CreateMailAddress
}
func (*CreateMailAddressRequestBody) MarshalJSON ¶
func (a *CreateMailAddressRequestBody) MarshalJSON() ([]byte, error)
func (*CreateMailAddressRequestBody) UnmarshalJSON ¶
func (a *CreateMailAddressRequestBody) UnmarshalJSON(input []byte) error
func (*CreateMailAddressRequestBody) Validate ¶
func (a *CreateMailAddressRequestBody) Validate() error
type CreateMailAddressResponse ¶
type CreateMailAddressResponse struct {
Id string `json:"id"`
}
func (*CreateMailAddressResponse) Validate ¶
func (o *CreateMailAddressResponse) Validate() error
type DeleteDeliveryBoxRequest ¶
type DeleteDeliveryBoxRequest struct {
DeliveryBoxID string
}
DeleteDeliveryBoxRequest models a request for the 'mail-delete-delivery-box' operation. See [1] for more information.
Delete a DeliveryBox.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-delete-delivery-box
func (*DeleteDeliveryBoxRequest) BuildRequest ¶
func (r *DeleteDeliveryBoxRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeleteMailAddressRequest ¶
type DeleteMailAddressRequest struct {
MailAddressID string
}
DeleteMailAddressRequest models a request for the 'mail-delete-mail-address' operation. See [1] for more information.
Delete a MailAddress.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-delete-mail-address
func (*DeleteMailAddressRequest) BuildRequest ¶
func (r *DeleteMailAddressRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedMailaddressUpdateAddressRequest ¶
type DeprecatedMailaddressUpdateAddressRequest struct {
Body DeprecatedMailaddressUpdateAddressRequestBody
ID string
}
DeprecatedMailaddressUpdateAddressRequest models a request for the 'deprecated-mail-mailaddress-update-address' operation. See [1] for more information.
Update mail-address ¶
This operation is deprecated. Use the PATCH v2/mail-addresses/{mailAddressId}/address endpoint instead.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/deprecated-mail-mailaddress-update-address
func (*DeprecatedMailaddressUpdateAddressRequest) BuildRequest ¶
func (r *DeprecatedMailaddressUpdateAddressRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedMailaddressUpdateAddressRequestBody ¶
type DeprecatedMailaddressUpdateAddressRequestBody struct {
Address string `json:"address"`
}
DeprecatedMailaddressUpdateAddressRequestBody models the JSON body of a 'deprecated-mail-mailaddress-update-address' request
func (*DeprecatedMailaddressUpdateAddressRequestBody) Validate ¶
func (o *DeprecatedMailaddressUpdateAddressRequestBody) Validate() error
type DeprecatedProjectsettingUpdateBlacklistRequest ¶
type DeprecatedProjectsettingUpdateBlacklistRequest struct {
Body DeprecatedProjectsettingUpdateBlacklistRequestBody
ProjectID string
}
DeprecatedProjectsettingUpdateBlacklistRequest models a request for the 'deprecated-mail-projectsetting-update-blacklist' operation. See [1] for more information.
Update blacklist for a given project ID ¶
This operation is deprecated. Use the PATCH v2/{projectId}/mail-settings/{mailSetting} endpoint instead.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/deprecated-mail-projectsetting-update-blacklist
func (*DeprecatedProjectsettingUpdateBlacklistRequest) BuildRequest ¶
func (r *DeprecatedProjectsettingUpdateBlacklistRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedProjectsettingUpdateBlacklistRequestBody ¶
type DeprecatedProjectsettingUpdateBlacklistRequestBody struct {
Blacklist []string `json:"blacklist"`
}
DeprecatedProjectsettingUpdateBlacklistRequestBody models the JSON body of a 'deprecated-mail-projectsetting-update-blacklist' request
func (*DeprecatedProjectsettingUpdateBlacklistRequestBody) Validate ¶
func (o *DeprecatedProjectsettingUpdateBlacklistRequestBody) Validate() error
type DeprecatedProjectsettingUpdateWhitelistRequest ¶
type DeprecatedProjectsettingUpdateWhitelistRequest struct {
Body DeprecatedProjectsettingUpdateWhitelistRequestBody
ProjectID string
}
DeprecatedProjectsettingUpdateWhitelistRequest models a request for the 'deprecated-mail-projectsetting-update-whitelist' operation. See [1] for more information.
Update whitelist for a given project ID ¶
This operation is deprecated. Use the PATCH v2/{projectId}/mail-settings/{mailSetting} endpoint instead.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/deprecated-mail-projectsetting-update-whitelist
func (*DeprecatedProjectsettingUpdateWhitelistRequest) BuildRequest ¶
func (r *DeprecatedProjectsettingUpdateWhitelistRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedProjectsettingUpdateWhitelistRequestBody ¶
type DeprecatedProjectsettingUpdateWhitelistRequestBody struct {
Whitelist []string `json:"whitelist"`
}
DeprecatedProjectsettingUpdateWhitelistRequestBody models the JSON body of a 'deprecated-mail-projectsetting-update-whitelist' request
func (*DeprecatedProjectsettingUpdateWhitelistRequestBody) Validate ¶
func (o *DeprecatedProjectsettingUpdateWhitelistRequestBody) Validate() error
type DeprecatedUpdateDescriptionRequest ¶
type DeprecatedUpdateDescriptionRequest struct {
Body DeprecatedUpdateDescriptionRequestBody
ID string
}
DeprecatedUpdateDescriptionRequest models a request for the 'deprecated-mail-deliverybox-update-description' operation. See [1] for more information.
Update the description of an deliverybox ¶
This operation is deprecated. Use the PATCH v2/delivery-boxes/{deliveryBoxId}/description endpoint instead.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/deprecated-mail-deliverybox-update-description
func (*DeprecatedUpdateDescriptionRequest) BuildRequest ¶
func (r *DeprecatedUpdateDescriptionRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedUpdateDescriptionRequestBody ¶
type DeprecatedUpdateDescriptionRequestBody struct {
Description string `json:"description"`
}
DeprecatedUpdateDescriptionRequestBody models the JSON body of a 'deprecated-mail-deliverybox-update-description' request
func (*DeprecatedUpdateDescriptionRequestBody) Validate ¶
func (o *DeprecatedUpdateDescriptionRequestBody) Validate() error
type DeprecatedUpdateMailAddressAutoresponderRequest ¶
type DeprecatedUpdateMailAddressAutoresponderRequest struct {
Body DeprecatedUpdateMailAddressAutoresponderRequestBody
MailAddressID string
}
DeprecatedUpdateMailAddressAutoresponderRequest models a request for the 'deprecated-mail-update-mail-address-autoresponder' operation. See [1] for more information.
Update the autoresponder of a MailAddress.
This operation is deprecated. Use the PATCH v2/mail-addresses/{mailAddressId}/autoresponder endpoint instead.
func (*DeprecatedUpdateMailAddressAutoresponderRequest) BuildRequest ¶
func (r *DeprecatedUpdateMailAddressAutoresponderRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedUpdateMailAddressAutoresponderRequestBody ¶
type DeprecatedUpdateMailAddressAutoresponderRequestBody struct {
AutoResponder DeprecatedUpdateMailAddressAutoresponderRequestBodyAutoResponder `json:"autoResponder"`
}
DeprecatedUpdateMailAddressAutoresponderRequestBody models the JSON body of a 'deprecated-mail-update-mail-address-autoresponder' request
func (*DeprecatedUpdateMailAddressAutoresponderRequestBody) Validate ¶
func (o *DeprecatedUpdateMailAddressAutoresponderRequestBody) Validate() error
type DeprecatedUpdateMailAddressAutoresponderRequestBodyAutoResponder ¶
type DeprecatedUpdateMailAddressAutoresponderRequestBodyAutoResponder struct {
Active bool `json:"active"`
ExpiresAt *time.Time `json:"expiresAt,omitempty"`
Message string `json:"message"`
StartsAt *time.Time `json:"startsAt,omitempty"`
}
func (*DeprecatedUpdateMailAddressAutoresponderRequestBodyAutoResponder) Validate ¶
func (o *DeprecatedUpdateMailAddressAutoresponderRequestBodyAutoResponder) Validate() error
type DeprecatedUpdateMailAddressCatchallRequest ¶
type DeprecatedUpdateMailAddressCatchallRequest struct {
Body DeprecatedUpdateMailAddressCatchallRequestBody
MailAddressID string
}
DeprecatedUpdateMailAddressCatchallRequest models a request for the 'deprecated-mail-update-mail-address-catchall' operation. See [1] for more information.
Update the catchall of a MailAddress.
This operation is deprecated. Use the PATCH v2/mail-addresses/{mailAddressId}/catch-all endpoint instead.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/deprecated-mail-update-mail-address-catchall
func (*DeprecatedUpdateMailAddressCatchallRequest) BuildRequest ¶
func (r *DeprecatedUpdateMailAddressCatchallRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedUpdateMailAddressCatchallRequestBody ¶
type DeprecatedUpdateMailAddressCatchallRequestBody struct {
Active bool `json:"active"`
}
DeprecatedUpdateMailAddressCatchallRequestBody models the JSON body of a 'deprecated-mail-update-mail-address-catchall' request
func (*DeprecatedUpdateMailAddressCatchallRequestBody) Validate ¶
func (o *DeprecatedUpdateMailAddressCatchallRequestBody) Validate() error
type DeprecatedUpdateMailAddressForwardAddressesRequest ¶
type DeprecatedUpdateMailAddressForwardAddressesRequest struct {
Body DeprecatedUpdateMailAddressForwardAddressesRequestBody
MailAddressID string
}
DeprecatedUpdateMailAddressForwardAddressesRequest models a request for the 'deprecated-mail-update-mail-address-forward-addresses' operation. See [1] for more information.
Update the forward addresses of a MailAddresses.
This operation is deprecated. Use the PATCH v2/mail-addresses/{mailAddressId}/forward-addresses endpoint instead.
func (*DeprecatedUpdateMailAddressForwardAddressesRequest) BuildRequest ¶
func (r *DeprecatedUpdateMailAddressForwardAddressesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedUpdateMailAddressForwardAddressesRequestBody ¶
type DeprecatedUpdateMailAddressForwardAddressesRequestBody struct {
ForwardAddresses []string `json:"forwardAddresses"`
}
DeprecatedUpdateMailAddressForwardAddressesRequestBody models the JSON body of a 'deprecated-mail-update-mail-address-forward-addresses' request
func (*DeprecatedUpdateMailAddressForwardAddressesRequestBody) Validate ¶
func (o *DeprecatedUpdateMailAddressForwardAddressesRequestBody) Validate() error
type DeprecatedUpdateMailAddressPasswordRequest ¶
type DeprecatedUpdateMailAddressPasswordRequest struct {
Body DeprecatedUpdateMailAddressPasswordRequestBody
MailAddressID string
}
DeprecatedUpdateMailAddressPasswordRequest models a request for the 'deprecated-mail-update-mail-address-password' operation. See [1] for more information.
Update the password for a MailAddress.
This operation is deprecated. Use the PATCH v2/mail-addresses/{mailAddressId}/password endpoint instead.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/deprecated-mail-update-mail-address-password
func (*DeprecatedUpdateMailAddressPasswordRequest) BuildRequest ¶
func (r *DeprecatedUpdateMailAddressPasswordRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedUpdateMailAddressPasswordRequestBody ¶
type DeprecatedUpdateMailAddressPasswordRequestBody struct {
Password string `json:"password"`
}
DeprecatedUpdateMailAddressPasswordRequestBody models the JSON body of a 'deprecated-mail-update-mail-address-password' request
func (*DeprecatedUpdateMailAddressPasswordRequestBody) Validate ¶
func (o *DeprecatedUpdateMailAddressPasswordRequestBody) Validate() error
type DeprecatedUpdateMailAddressQuotaRequest ¶
type DeprecatedUpdateMailAddressQuotaRequest struct {
Body DeprecatedUpdateMailAddressQuotaRequestBody
MailAddressID string
}
DeprecatedUpdateMailAddressQuotaRequest models a request for the 'deprecated-mail-update-mail-address-quota' operation. See [1] for more information.
Update the quota of a MailAddress.
This operation is deprecated. Use the PATCH v2/mail-addresses/{mailAddressId}/quota endpoint instead.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/deprecated-mail-update-mail-address-quota
func (*DeprecatedUpdateMailAddressQuotaRequest) BuildRequest ¶
func (r *DeprecatedUpdateMailAddressQuotaRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedUpdateMailAddressQuotaRequestBody ¶
type DeprecatedUpdateMailAddressQuotaRequestBody struct {
QuotaInBytes float64 `json:"quotaInBytes"`
}
DeprecatedUpdateMailAddressQuotaRequestBody models the JSON body of a 'deprecated-mail-update-mail-address-quota' request
func (*DeprecatedUpdateMailAddressQuotaRequestBody) Validate ¶
func (o *DeprecatedUpdateMailAddressQuotaRequestBody) Validate() error
type DeprecatedUpdateMailAddressSpamProtectionRequest ¶
type DeprecatedUpdateMailAddressSpamProtectionRequest struct {
Body DeprecatedUpdateMailAddressSpamProtectionRequestBody
MailAddressID string
}
DeprecatedUpdateMailAddressSpamProtectionRequest models a request for the 'deprecated-mail-update-mail-address-spam-protection' operation. See [1] for more information.
Update the spam protection of a MailAddress.
This operation is deprecated. Use the PATCH v2/mail-addresses/{mailAddressId}/spam-protection endpoint instead.
func (*DeprecatedUpdateMailAddressSpamProtectionRequest) BuildRequest ¶
func (r *DeprecatedUpdateMailAddressSpamProtectionRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedUpdateMailAddressSpamProtectionRequestBody ¶
type DeprecatedUpdateMailAddressSpamProtectionRequestBody struct {
SpamProtection DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtection `json:"spamProtection"`
}
DeprecatedUpdateMailAddressSpamProtectionRequestBody models the JSON body of a 'deprecated-mail-update-mail-address-spam-protection' request
func (*DeprecatedUpdateMailAddressSpamProtectionRequestBody) Validate ¶
func (o *DeprecatedUpdateMailAddressSpamProtectionRequestBody) Validate() error
type DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtection ¶
type DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtection struct {
Active bool `json:"active"`
AutoDeleteSpam bool `json:"autoDeleteSpam"`
Folder DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder `json:"folder"`
RelocationMinSpamScore int64 `json:"relocationMinSpamScore"`
}
func (*DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtection) Validate ¶
func (o *DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtection) Validate() error
type DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder ¶
type DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder string
const DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtectionFolderInbox DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder = "inbox"
const DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtectionFolderSpam DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder = "spam"
func (DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder) Validate ¶
func (e DeprecatedUpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder) Validate() error
type DeprecatedUpdatePasswordRequest ¶
type DeprecatedUpdatePasswordRequest struct {
Body DeprecatedUpdatePasswordRequestBody
ID string
}
DeprecatedUpdatePasswordRequest models a request for the 'deprecated-mail-deliverybox-update-password' operation. See [1] for more information.
Update the password for a specific deliverybox ¶
This operation is deprecated. Use the PATCH v2/delivery-boxes/{deliveryBoxId}/password endpoint instead.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/deprecated-mail-deliverybox-update-password
func (*DeprecatedUpdatePasswordRequest) BuildRequest ¶
func (r *DeprecatedUpdatePasswordRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedUpdatePasswordRequestBody ¶
type DeprecatedUpdatePasswordRequestBody struct {
Password string `json:"password"`
}
DeprecatedUpdatePasswordRequestBody models the JSON body of a 'deprecated-mail-deliverybox-update-password' request
func (*DeprecatedUpdatePasswordRequestBody) Validate ¶
func (o *DeprecatedUpdatePasswordRequestBody) Validate() error
type DeprecatedUpdateProjectMailSettingRequest ¶
type DeprecatedUpdateProjectMailSettingRequest struct {
Body DeprecatedUpdateProjectMailSettingRequestBody
ProjectID string
Setting DeprecatedUpdateProjectMailSettingRequestPathSetting
}
DeprecatedUpdateProjectMailSettingRequest models a request for the 'deprecated-mail-update-project-mail-setting' operation. See [1] for more information.
Update a mail setting of a Project.
This operation is deprecated. Use the PATCH v2/{projectId}/mail-settings/{mailSetting} endpoint instead.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/deprecated-mail-update-project-mail-setting
func (*DeprecatedUpdateProjectMailSettingRequest) BuildRequest ¶
func (r *DeprecatedUpdateProjectMailSettingRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type DeprecatedUpdateProjectMailSettingRequestBody ¶
type DeprecatedUpdateProjectMailSettingRequestBody struct {
AlternativeDeprecatedUpdateProjectMailSettingRequestBodyAlternative1 *DeprecatedUpdateProjectMailSettingRequestBodyAlternative1
AlternativeDeprecatedUpdateProjectMailSettingRequestBodyAlternative2 *DeprecatedUpdateProjectMailSettingRequestBodyAlternative2
}
func (*DeprecatedUpdateProjectMailSettingRequestBody) MarshalJSON ¶
func (a *DeprecatedUpdateProjectMailSettingRequestBody) MarshalJSON() ([]byte, error)
func (*DeprecatedUpdateProjectMailSettingRequestBody) UnmarshalJSON ¶
func (a *DeprecatedUpdateProjectMailSettingRequestBody) UnmarshalJSON(input []byte) error
func (*DeprecatedUpdateProjectMailSettingRequestBody) Validate ¶
func (a *DeprecatedUpdateProjectMailSettingRequestBody) Validate() error
type DeprecatedUpdateProjectMailSettingRequestBodyAlternative1 ¶
type DeprecatedUpdateProjectMailSettingRequestBodyAlternative1 struct {
Blacklist []string `json:"blacklist"`
}
func (*DeprecatedUpdateProjectMailSettingRequestBodyAlternative1) Validate ¶
func (o *DeprecatedUpdateProjectMailSettingRequestBodyAlternative1) Validate() error
type DeprecatedUpdateProjectMailSettingRequestBodyAlternative2 ¶
type DeprecatedUpdateProjectMailSettingRequestBodyAlternative2 struct {
Whitelist []string `json:"whitelist"`
}
func (*DeprecatedUpdateProjectMailSettingRequestBodyAlternative2) Validate ¶
func (o *DeprecatedUpdateProjectMailSettingRequestBodyAlternative2) Validate() error
type DeprecatedUpdateProjectMailSettingRequestPathSetting ¶
type DeprecatedUpdateProjectMailSettingRequestPathSetting string
const DeprecatedUpdateProjectMailSettingRequestPathSettingBlacklist DeprecatedUpdateProjectMailSettingRequestPathSetting = "blacklist"
const DeprecatedUpdateProjectMailSettingRequestPathSettingWhitelist DeprecatedUpdateProjectMailSettingRequestPathSetting = "whitelist"
func (DeprecatedUpdateProjectMailSettingRequestPathSetting) Validate ¶
func (e DeprecatedUpdateProjectMailSettingRequestPathSetting) Validate() error
type GetDeliveryBoxRequest ¶
type GetDeliveryBoxRequest struct {
DeliveryBoxID string
}
GetDeliveryBoxRequest models a request for the 'mail-get-delivery-box' operation. See 1 for more information.
Get a DeliveryBox.
func (*GetDeliveryBoxRequest) BuildRequest ¶
func (r *GetDeliveryBoxRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type GetMailAddressRequest ¶
type GetMailAddressRequest struct {
MailAddressID string
}
GetMailAddressRequest models a request for the 'mail-get-mail-address' operation. See 1 for more information.
Get a MailAddress.
func (*GetMailAddressRequest) BuildRequest ¶
func (r *GetMailAddressRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type ListDeliveryBoxesRequest ¶
type ListDeliveryBoxesRequest struct {
ProjectID string
Search *string
Limit *int64
Skip *int64
Page *int64
}
ListDeliveryBoxesRequest models a request for the 'mail-list-delivery-boxes' operation. See [1] for more information.
List DeliveryBoxes belonging to a Project.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-list-delivery-boxes
func (*ListDeliveryBoxesRequest) BuildRequest ¶
func (r *ListDeliveryBoxesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type ListMailAddressesRequest ¶
type ListMailAddressesRequest struct {
ProjectID string
Search *string
ForwardAddress *bool
CatchAll *bool
AutoResponder *bool
Limit *int64
Skip *int64
Page *int64
Sort []ListMailAddressesRequestQuerySortItem
Order []ListMailAddressesRequestQueryOrderItem
}
ListMailAddressesRequest models a request for the 'mail-list-mail-addresses' operation. See [1] for more information.
List MailAddresses belonging to a Project.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-list-mail-addresses
func (*ListMailAddressesRequest) BuildRequest ¶
func (r *ListMailAddressesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type ListMailAddressesRequestQueryOrderItem ¶ added in v0.2.39
type ListMailAddressesRequestQueryOrderItem string
const ListMailAddressesRequestQueryOrderItemAsc ListMailAddressesRequestQueryOrderItem = "asc"
const ListMailAddressesRequestQueryOrderItemDesc ListMailAddressesRequestQueryOrderItem = "desc"
func (ListMailAddressesRequestQueryOrderItem) Validate ¶ added in v0.2.39
func (e ListMailAddressesRequestQueryOrderItem) Validate() error
type ListMailAddressesRequestQuerySortItem ¶ added in v0.2.39
type ListMailAddressesRequestQuerySortItem string
const ListMailAddressesRequestQuerySortItemAddressDomain ListMailAddressesRequestQuerySortItem = "address.domain"
const ListMailAddressesRequestQuerySortItemAddressLocal ListMailAddressesRequestQuerySortItem = "address.local"
const ListMailAddressesRequestQuerySortItemMailboxName ListMailAddressesRequestQuerySortItem = "mailbox.name"
const ListMailAddressesRequestQuerySortItemMailboxQuota ListMailAddressesRequestQuerySortItem = "mailbox.quota"
const ListMailAddressesRequestQuerySortItemMailboxStorageInBytesCurrent ListMailAddressesRequestQuerySortItem = "mailbox.storageInBytes.current"
const ListMailAddressesRequestQuerySortItemMailboxStorageInBytesLimit ListMailAddressesRequestQuerySortItem = "mailbox.storageInBytes.limit"
const ListMailAddressesRequestQuerySortItemProjectID ListMailAddressesRequestQuerySortItem = "projectId"
const ListMailAddressesRequestQuerySortItemUpdatedAt ListMailAddressesRequestQuerySortItem = "updatedAt"
func (ListMailAddressesRequestQuerySortItem) Validate ¶ added in v0.2.39
func (e ListMailAddressesRequestQuerySortItem) Validate() error
type ListProjectMailSettingsRequest ¶
type ListProjectMailSettingsRequest struct {
ProjectID string
}
ListProjectMailSettingsRequest models a request for the 'mail-list-project-mail-settings' operation. See [1] for more information.
List mail settings of a Project.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-list-project-mail-settings
func (*ListProjectMailSettingsRequest) BuildRequest ¶
func (r *ListProjectMailSettingsRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type ListProjectMailSettingsResponse ¶
type ListProjectMailSettingsResponse struct {
Blacklist []string `json:"blacklist"`
ProjectId string `json:"projectId"`
Whitelist []string `json:"whitelist"`
}
func (*ListProjectMailSettingsResponse) Validate ¶
func (o *ListProjectMailSettingsResponse) Validate() error
type UpdateDeliveryBoxDescriptionRequest ¶
type UpdateDeliveryBoxDescriptionRequest struct {
Body UpdateDeliveryBoxDescriptionRequestBody
DeliveryBoxID string
}
UpdateDeliveryBoxDescriptionRequest models a request for the 'mail-update-delivery-box-description' operation. See [1] for more information.
Update the description of a DeliveryBox.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-update-delivery-box-description
func (*UpdateDeliveryBoxDescriptionRequest) BuildRequest ¶
func (r *UpdateDeliveryBoxDescriptionRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type UpdateDeliveryBoxDescriptionRequestBody ¶
type UpdateDeliveryBoxDescriptionRequestBody struct {
Description string `json:"description"`
}
UpdateDeliveryBoxDescriptionRequestBody models the JSON body of a 'mail-update-delivery-box-description' request
func (*UpdateDeliveryBoxDescriptionRequestBody) Validate ¶
func (o *UpdateDeliveryBoxDescriptionRequestBody) Validate() error
type UpdateDeliveryBoxPasswordRequest ¶
type UpdateDeliveryBoxPasswordRequest struct {
Body UpdateDeliveryBoxPasswordRequestBody
DeliveryBoxID string
}
UpdateDeliveryBoxPasswordRequest models a request for the 'mail-update-delivery-box-password' operation. See [1] for more information.
Update the password of a DeliveryBox.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-update-delivery-box-password
func (*UpdateDeliveryBoxPasswordRequest) BuildRequest ¶
func (r *UpdateDeliveryBoxPasswordRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type UpdateDeliveryBoxPasswordRequestBody ¶
type UpdateDeliveryBoxPasswordRequestBody struct {
Password string `json:"password"`
}
UpdateDeliveryBoxPasswordRequestBody models the JSON body of a 'mail-update-delivery-box-password' request
func (*UpdateDeliveryBoxPasswordRequestBody) Validate ¶
func (o *UpdateDeliveryBoxPasswordRequestBody) Validate() error
type UpdateMailAddressAddressRequest ¶
type UpdateMailAddressAddressRequest struct {
Body UpdateMailAddressAddressRequestBody
MailAddressID string
}
UpdateMailAddressAddressRequest models a request for the 'mail-update-mail-address-address' operation. See [1] for more information.
Update a MailAddress.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-update-mail-address-address
func (*UpdateMailAddressAddressRequest) BuildRequest ¶
func (r *UpdateMailAddressAddressRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type UpdateMailAddressAddressRequestBody ¶
type UpdateMailAddressAddressRequestBody struct {
Address string `json:"address"`
}
UpdateMailAddressAddressRequestBody models the JSON body of a 'mail-update-mail-address-address' request
func (*UpdateMailAddressAddressRequestBody) Validate ¶
func (o *UpdateMailAddressAddressRequestBody) Validate() error
type UpdateMailAddressAutoresponderRequest ¶
type UpdateMailAddressAutoresponderRequest struct {
Body UpdateMailAddressAutoresponderRequestBody
MailAddressID string
}
UpdateMailAddressAutoresponderRequest models a request for the 'mail-update-mail-address-autoresponder' operation. See [1] for more information.
Update the autoresponder of a MailAddress.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-update-mail-address-autoresponder
func (*UpdateMailAddressAutoresponderRequest) BuildRequest ¶
func (r *UpdateMailAddressAutoresponderRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type UpdateMailAddressAutoresponderRequestBody ¶
type UpdateMailAddressAutoresponderRequestBody struct {
AutoResponder UpdateMailAddressAutoresponderRequestBodyAutoResponder `json:"autoResponder"`
}
UpdateMailAddressAutoresponderRequestBody models the JSON body of a 'mail-update-mail-address-autoresponder' request
func (*UpdateMailAddressAutoresponderRequestBody) Validate ¶
func (o *UpdateMailAddressAutoresponderRequestBody) Validate() error
type UpdateMailAddressAutoresponderRequestBodyAutoResponder ¶
type UpdateMailAddressAutoresponderRequestBodyAutoResponder struct {
Active bool `json:"active"`
ExpiresAt *time.Time `json:"expiresAt,omitempty"`
Message string `json:"message"`
StartsAt *time.Time `json:"startsAt,omitempty"`
}
func (*UpdateMailAddressAutoresponderRequestBodyAutoResponder) Validate ¶
func (o *UpdateMailAddressAutoresponderRequestBodyAutoResponder) Validate() error
type UpdateMailAddressCatchAllRequest ¶
type UpdateMailAddressCatchAllRequest struct {
Body UpdateMailAddressCatchAllRequestBody
MailAddressID string
}
UpdateMailAddressCatchAllRequest models a request for the 'mail-update-mail-address-catch-all' operation. See [1] for more information.
Update the catch-all of a MailAddress.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-update-mail-address-catch-all
func (*UpdateMailAddressCatchAllRequest) BuildRequest ¶
func (r *UpdateMailAddressCatchAllRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type UpdateMailAddressCatchAllRequestBody ¶
type UpdateMailAddressCatchAllRequestBody struct {
Active bool `json:"active"`
}
UpdateMailAddressCatchAllRequestBody models the JSON body of a 'mail-update-mail-address-catch-all' request
func (*UpdateMailAddressCatchAllRequestBody) Validate ¶
func (o *UpdateMailAddressCatchAllRequestBody) Validate() error
type UpdateMailAddressForwardAddressesRequest ¶
type UpdateMailAddressForwardAddressesRequest struct {
Body UpdateMailAddressForwardAddressesRequestBody
MailAddressID string
}
UpdateMailAddressForwardAddressesRequest models a request for the 'mail-update-mail-address-forward-addresses' operation. See [1] for more information.
Update the forward addresses of a MailAddresses.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-update-mail-address-forward-addresses
func (*UpdateMailAddressForwardAddressesRequest) BuildRequest ¶
func (r *UpdateMailAddressForwardAddressesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type UpdateMailAddressForwardAddressesRequestBody ¶
type UpdateMailAddressForwardAddressesRequestBody struct {
ForwardAddresses []string `json:"forwardAddresses"`
}
UpdateMailAddressForwardAddressesRequestBody models the JSON body of a 'mail-update-mail-address-forward-addresses' request
func (*UpdateMailAddressForwardAddressesRequestBody) Validate ¶
func (o *UpdateMailAddressForwardAddressesRequestBody) Validate() error
type UpdateMailAddressPasswordRequest ¶
type UpdateMailAddressPasswordRequest struct {
Body UpdateMailAddressPasswordRequestBody
MailAddressID string
}
UpdateMailAddressPasswordRequest models a request for the 'mail-update-mail-address-password' operation. See [1] for more information.
Update the password for a MailAddress.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-update-mail-address-password
func (*UpdateMailAddressPasswordRequest) BuildRequest ¶
func (r *UpdateMailAddressPasswordRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type UpdateMailAddressPasswordRequestBody ¶
type UpdateMailAddressPasswordRequestBody struct {
Password string `json:"password"`
}
UpdateMailAddressPasswordRequestBody models the JSON body of a 'mail-update-mail-address-password' request
func (*UpdateMailAddressPasswordRequestBody) Validate ¶
func (o *UpdateMailAddressPasswordRequestBody) Validate() error
type UpdateMailAddressQuotaRequest ¶
type UpdateMailAddressQuotaRequest struct {
Body UpdateMailAddressQuotaRequestBody
MailAddressID string
}
UpdateMailAddressQuotaRequest models a request for the 'mail-update-mail-address-quota' operation. See [1] for more information.
Update the quota of a MailAddress.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-update-mail-address-quota
func (*UpdateMailAddressQuotaRequest) BuildRequest ¶
func (r *UpdateMailAddressQuotaRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type UpdateMailAddressQuotaRequestBody ¶
type UpdateMailAddressQuotaRequestBody struct {
QuotaInBytes float64 `json:"quotaInBytes"`
}
UpdateMailAddressQuotaRequestBody models the JSON body of a 'mail-update-mail-address-quota' request
func (*UpdateMailAddressQuotaRequestBody) Validate ¶
func (o *UpdateMailAddressQuotaRequestBody) Validate() error
type UpdateMailAddressSpamProtectionRequest ¶
type UpdateMailAddressSpamProtectionRequest struct {
Body UpdateMailAddressSpamProtectionRequestBody
MailAddressID string
}
UpdateMailAddressSpamProtectionRequest models a request for the 'mail-update-mail-address-spam-protection' operation. See [1] for more information.
Update the spam protection of a MailAddress.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-update-mail-address-spam-protection
func (*UpdateMailAddressSpamProtectionRequest) BuildRequest ¶
func (r *UpdateMailAddressSpamProtectionRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type UpdateMailAddressSpamProtectionRequestBody ¶
type UpdateMailAddressSpamProtectionRequestBody struct {
SpamProtection UpdateMailAddressSpamProtectionRequestBodySpamProtection `json:"spamProtection"`
}
UpdateMailAddressSpamProtectionRequestBody models the JSON body of a 'mail-update-mail-address-spam-protection' request
func (*UpdateMailAddressSpamProtectionRequestBody) Validate ¶
func (o *UpdateMailAddressSpamProtectionRequestBody) Validate() error
type UpdateMailAddressSpamProtectionRequestBodySpamProtection ¶
type UpdateMailAddressSpamProtectionRequestBodySpamProtection struct {
Active bool `json:"active"`
AutoDeleteSpam bool `json:"autoDeleteSpam"`
Folder UpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder `json:"folder"`
RelocationMinSpamScore int64 `json:"relocationMinSpamScore"`
}
func (*UpdateMailAddressSpamProtectionRequestBodySpamProtection) Validate ¶
func (o *UpdateMailAddressSpamProtectionRequestBodySpamProtection) Validate() error
type UpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder ¶
type UpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder string
const UpdateMailAddressSpamProtectionRequestBodySpamProtectionFolderInbox UpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder = "inbox"
const UpdateMailAddressSpamProtectionRequestBodySpamProtectionFolderSpam UpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder = "spam"
func (UpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder) Validate ¶
func (e UpdateMailAddressSpamProtectionRequestBodySpamProtectionFolder) Validate() error
type UpdateProjectMailSettingRequest ¶
type UpdateProjectMailSettingRequest struct {
Body UpdateProjectMailSettingRequestBody
ProjectID string
MailSetting UpdateProjectMailSettingRequestPathMailSetting
}
UpdateProjectMailSettingRequest models a request for the 'mail-update-project-mail-setting' operation. See [1] for more information.
Update a mail setting of a Project.
[1]: https://developer.mittwald.de/docs/v2/reference/mail/mail-update-project-mail-setting
func (*UpdateProjectMailSettingRequest) BuildRequest ¶
func (r *UpdateProjectMailSettingRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type UpdateProjectMailSettingRequestBody ¶
type UpdateProjectMailSettingRequestBody struct {
AlternativeUpdateProjectMailSettingRequestBodyAlternative1 *UpdateProjectMailSettingRequestBodyAlternative1
AlternativeUpdateProjectMailSettingRequestBodyAlternative2 *UpdateProjectMailSettingRequestBodyAlternative2
}
func (*UpdateProjectMailSettingRequestBody) MarshalJSON ¶
func (a *UpdateProjectMailSettingRequestBody) MarshalJSON() ([]byte, error)
func (*UpdateProjectMailSettingRequestBody) UnmarshalJSON ¶
func (a *UpdateProjectMailSettingRequestBody) UnmarshalJSON(input []byte) error
func (*UpdateProjectMailSettingRequestBody) Validate ¶
func (a *UpdateProjectMailSettingRequestBody) Validate() error
type UpdateProjectMailSettingRequestBodyAlternative1 ¶
type UpdateProjectMailSettingRequestBodyAlternative1 struct {
Blacklist []string `json:"blacklist"`
}
func (*UpdateProjectMailSettingRequestBodyAlternative1) Validate ¶
func (o *UpdateProjectMailSettingRequestBodyAlternative1) Validate() error
type UpdateProjectMailSettingRequestBodyAlternative2 ¶
type UpdateProjectMailSettingRequestBodyAlternative2 struct {
Whitelist []string `json:"whitelist"`
}
func (*UpdateProjectMailSettingRequestBodyAlternative2) Validate ¶
func (o *UpdateProjectMailSettingRequestBodyAlternative2) Validate() error
type UpdateProjectMailSettingRequestPathMailSetting ¶
type UpdateProjectMailSettingRequestPathMailSetting string
const UpdateProjectMailSettingRequestPathMailSettingBlacklist UpdateProjectMailSettingRequestPathMailSetting = "blacklist"
const UpdateProjectMailSettingRequestPathMailSettingWhitelist UpdateProjectMailSettingRequestPathMailSetting = "whitelist"
func (UpdateProjectMailSettingRequestPathMailSetting) Validate ¶
func (e UpdateProjectMailSettingRequestPathMailSetting) Validate() error
Source Files
¶
- client.go
- createdeliverybox_request.go
- createdeliverybox_request_body.go
- createdeliverybox_response.go
- createmailaddress_request.go
- createmailaddress_request_body.go
- createmailaddress_response.go
- deletedeliverybox_request.go
- deletemailaddress_request.go
- deprecatedmailaddressupdateaddress_request.go
- deprecatedmailaddressupdateaddress_request_body.go
- deprecatedprojectsettingupdateblacklist_request.go
- deprecatedprojectsettingupdateblacklist_request_body.go
- deprecatedprojectsettingupdatewhitelist_request.go
- deprecatedprojectsettingupdatewhitelist_request_body.go
- deprecatedupdatedescription_request.go
- deprecatedupdatedescription_request_body.go
- deprecatedupdatemailaddressautoresponder_request.go
- deprecatedupdatemailaddressautoresponder_request_body.go
- deprecatedupdatemailaddressautoresponder_request_body_autoresponder.go
- deprecatedupdatemailaddresscatchall_request.go
- deprecatedupdatemailaddresscatchall_request_body.go
- deprecatedupdatemailaddressforwardaddresses_request.go
- deprecatedupdatemailaddressforwardaddresses_request_body.go
- deprecatedupdatemailaddresspassword_request.go
- deprecatedupdatemailaddresspassword_request_body.go
- deprecatedupdatemailaddressquota_request.go
- deprecatedupdatemailaddressquota_request_body.go
- deprecatedupdatemailaddressspamprotection_request.go
- deprecatedupdatemailaddressspamprotection_request_body.go
- deprecatedupdatemailaddressspamprotection_request_body_spamprotection.go
- deprecatedupdatemailaddressspamprotection_request_body_spamprotection_folder.go
- deprecatedupdatepassword_request.go
- deprecatedupdatepassword_request_body.go
- deprecatedupdateprojectmailsetting_request.go
- deprecatedupdateprojectmailsetting_request_body.go
- deprecatedupdateprojectmailsetting_request_body_alternative1.go
- deprecatedupdateprojectmailsetting_request_body_alternative2.go
- deprecatedupdateprojectmailsetting_request_path_setting.go
- getdeliverybox_request.go
- getmailaddress_request.go
- listdeliveryboxes_request.go
- listmailaddresses_request.go
- listmailaddresses_request_query_order_item.go
- listmailaddresses_request_query_sort_item.go
- listprojectmailsettings_request.go
- listprojectmailsettings_response.go
- updatedeliveryboxdescription_request.go
- updatedeliveryboxdescription_request_body.go
- updatedeliveryboxpassword_request.go
- updatedeliveryboxpassword_request_body.go
- updatemailaddressaddress_request.go
- updatemailaddressaddress_request_body.go
- updatemailaddressautoresponder_request.go
- updatemailaddressautoresponder_request_body.go
- updatemailaddressautoresponder_request_body_autoresponder.go
- updatemailaddresscatchall_request.go
- updatemailaddresscatchall_request_body.go
- updatemailaddressforwardaddresses_request.go
- updatemailaddressforwardaddresses_request_body.go
- updatemailaddresspassword_request.go
- updatemailaddresspassword_request_body.go
- updatemailaddressquota_request.go
- updatemailaddressquota_request_body.go
- updatemailaddressspamprotection_request.go
- updatemailaddressspamprotection_request_body.go
- updatemailaddressspamprotection_request_body_spamprotection.go
- updatemailaddressspamprotection_request_body_spamprotection_folder.go
- updateprojectmailsetting_request.go
- updateprojectmailsetting_request_body.go
- updateprojectmailsetting_request_body_alternative1.go
- updateprojectmailsetting_request_body_alternative2.go
- updateprojectmailsetting_request_path_mailsetting.go