Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client interface {
ProjectFileSystemGetDirectories(
ctx context.Context,
req ProjectFileSystemGetDirectoriesRequest,
reqEditors ...func(req *http.Request) error,
) (*projectv2.FilesystemDirectoryListing, *http.Response, error)
ProjectFileSystemGetDiskUsage(
ctx context.Context,
req ProjectFileSystemGetDiskUsageRequest,
reqEditors ...func(req *http.Request) error,
) (*projectv2.FilesystemUsagesDisk, *http.Response, error)
ProjectFileSystemGetFileContent(
ctx context.Context,
req ProjectFileSystemGetFileContentRequest,
reqEditors ...func(req *http.Request) error,
) (*http.Response, error)
ProjectFileSystemGetJwt(
ctx context.Context,
req ProjectFileSystemGetJwtRequest,
reqEditors ...func(req *http.Request) error,
) (*projectv2.FsApiJwt, *http.Response, error)
ProjectFileSystemListFiles(
ctx context.Context,
req ProjectFileSystemListFilesRequest,
reqEditors ...func(req *http.Request) error,
) (*projectv2.FilesystemDirectoryListing, *http.Response, error)
}
func NewClient ¶
func NewClient(client httpclient.RequestRunner) Client
type ProjectFileSystemGetDirectoriesRequest ¶
type ProjectFileSystemGetDirectoriesRequest struct {
ProjectID string
Directory *string
Name *string
MaxDepth *int64
Type []string
Executable *bool
Hidden *bool
}
ProjectFileSystemGetDirectoriesRequest models a request for the 'project-file-system-get-directories' operation. See [1] for more information.
List directories belonging to a Project.
[1]: https://developer.mittwald.de/docs/v2/reference/project file system/project-file-system-get-directories
func (*ProjectFileSystemGetDirectoriesRequest) BuildRequest ¶
func (r *ProjectFileSystemGetDirectoriesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type ProjectFileSystemGetDiskUsageRequest ¶
ProjectFileSystemGetDiskUsageRequest models a request for the 'project-file-system-get-disk-usage' operation. See [1] for more information.
Get a Project directory filesystem usage.
[1]: https://developer.mittwald.de/docs/v2/reference/project file system/project-file-system-get-disk-usage
func (*ProjectFileSystemGetDiskUsageRequest) BuildRequest ¶
func (r *ProjectFileSystemGetDiskUsageRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type ProjectFileSystemGetFileContentRequest ¶
ProjectFileSystemGetFileContentRequest models a request for the 'project-file-system-get-file-content' operation. See [1] for more information.
Get a Project file's content.
[1]: https://developer.mittwald.de/docs/v2/reference/project file system/project-file-system-get-file-content
func (*ProjectFileSystemGetFileContentRequest) BuildRequest ¶
func (r *ProjectFileSystemGetFileContentRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type ProjectFileSystemGetJwtRequest ¶
type ProjectFileSystemGetJwtRequest struct {
ProjectID string
}
ProjectFileSystemGetJwtRequest models a request for the 'project-file-system-get-jwt' operation. See [1] for more information.
Get a Project's file/filesystem authorization token.
[1]: https://developer.mittwald.de/docs/v2/reference/project file system/project-file-system-get-jwt
func (*ProjectFileSystemGetJwtRequest) BuildRequest ¶
func (r *ProjectFileSystemGetJwtRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.
type ProjectFileSystemListFilesRequest ¶
ProjectFileSystemListFilesRequest models a request for the 'project-file-system-list-files' operation. See [1] for more information.
Get a Project file's information.
[1]: https://developer.mittwald.de/docs/v2/reference/project file system/project-file-system-list-files
func (*ProjectFileSystemListFilesRequest) BuildRequest ¶
func (r *ProjectFileSystemListFilesRequest) BuildRequest(reqEditors ...func(req *http.Request) error) (*http.Request, error)
BuildRequest builds an *http.Request instance from this request that may be used with any regular *http.Client instance.